@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999 - 2000 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1999 - 2000, 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -51,7 +51,7 @@
 #include <config.h>
 #endif
 
-RCSID("$Id: klog.c,v 1.29.2.1 2001/10/03 22:52:01 assar Exp $");
+RCSID("$Id: klog.c,v 1.29.2.3 2002/07/11 14:00:38 lha Exp $");
 
 #include "appl_locl.h"
 #include "klog.h"
@@ -364,27 +364,44 @@ do_timeout (int (*function)(void) )
  * use umich compat basename of ticket.
  */
 
-static const char *tktbasename[] = {
-    KLOG_TKT_ROOT,
-#if defined(HAVE_KRB_GET_DEFAULT_TKT_ROOT)
-    "",
-#elif defined(TKT_ROOT)
-    TKT_ROOT,
+#ifndef TKT_ROOT
+#define TKT_ROOT "/tmp"
 #endif
-    NULL
-};
 
 char *
 randfilename(void)
 {
-    const char *base, **basepath;
+    const char *base;
     char *filename;
-    int fd;
+    int fd, i;
 
-    for (basepath = tktbasename; (base = *basepath) != NULL; ++basepath) {
-#if defined(HAVE_KRB_GET_DEFAULT_TKT_ROOT)
-	base = krb_get_default_tkt_root ();
+    /* 
+     * this kind of sucks, before we use an array but in some kerberos
+     * dists TKT_ROOT isn't a constant (its a function) so we needed
+     * to stop using that.
+     */
+
+    for (i = 0; i < 3; i++) {
+	base = NULL;
+	switch (i) {
+#ifdef HAVE_KRB_GET_DEFAULT_TKT_ROOT
+	case 0:
+	    base = krb_get_default_tkt_root ();
+	    break;
 #endif
+	case 1:
+	    base = KLOG_TKT_ROOT;
+	    break;
+	case 2:
+	    base = TKT_ROOT;
+	    break;
+	default:
+	    abort();
+	}
+
+	if (base == NULL)
+	    continue;
+
 	asprintf (&filename, "%s_%u_XXXXXX", base, (unsigned)getuid());
 	if (filename == NULL)
 	    dietx (1, "out of memory");
@@ -481,9 +498,9 @@ main(int argc, char **argv)
 
     char pwbuf[PASSWD_MAX];
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
-    method = log_open (get_progname(), "/dev/stderr:notime");
+    method = log_open (getprogname(), "/dev/stderr:notime");
     if (method == NULL)
 	errx (1, "log_open failed");
     cell_init(0, method);
