@@ -31,7 +31,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: arlalib.h,v 1.37.2.1 2001/01/25 15:33:11 lha Exp $ */
+/* $Id: arlalib.h,v 1.37.2.3 2001/10/02 16:13:01 jimmy Exp $ */
 
 #ifndef ARLALIB_H
 #define ARLALIB_H 1
@@ -129,6 +129,8 @@ int fs_getaviatorstats(u_int32_t *max_workers,
 int fs_checkservers(char *cell, int32_t flags,
 		    u_int32_t *hosts, int numhosts);
 
+int fs_checkvolumes (void);
+
 int
 fs_set_sysname (const char *sys);
 
@@ -172,6 +174,14 @@ fs_rmmount (const char *path);
 int
 fs_incompat_renumber (int *ret);
 
+int
+fs_statistics_list(u_int32_t *host, u_int32_t *part, int *n);
+
+int
+fs_statistics_entry(u_int32_t host, u_int32_t part, u_int32_t type,
+		    u_int32_t items_slot, u_int32_t *count,
+		    int64_t *items_total, int64_t *total_time);
+
 int
 arlalib_get_viceid (const char *username, const char *cellname,
 		    int32_t *viceId);
