@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 1999 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1998 - 2000 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -34,7 +34,7 @@
 #include "appl_locl.h"
 #include <kafs.h>
 
-RCSID("$Id: fs_lib.c,v 1.31.2.1 2001/01/25 15:34:24 lha Exp $");
+RCSID("$Id: fs_lib.c,v 1.31.2.3 2001/10/02 16:13:02 jimmy Exp $");
 
 enum { PIOCTL_MAXSIZE = 2000 };
 
@@ -45,7 +45,7 @@ enum { PIOCTL_MAXSIZE = 2000 };
 const char *
 fslib_version(void)
 {
-    return "$Id: fs_lib.c,v 1.31.2.1 2001/01/25 15:34:24 lha Exp $";
+    return "$Id: fs_lib.c,v 1.31.2.3 2001/10/02 16:13:02 jimmy Exp $";
 }
 
 /*
@@ -572,6 +572,26 @@ fs_checkservers(char *cell, int32_t flags, u_int32_t *hosts, int numhosts)
     return ret;
 }
 
+/*
+ * check validity of cached volume information
+ */
+
+int
+fs_checkvolumes (void)
+{
+    struct ViceIoctl a_params;
+
+    a_params.in       = NULL;
+    a_params.in_size  = 0;
+    a_params.out      = NULL;
+    a_params.out_size = 0;
+
+    if (k_pioctl (NULL, VIOCCKBACK, &a_params, 0) < 0)
+	return errno;
+    else
+	return 0;
+}
+
 /*
  * return current sysname in `sys' (of max length `sys_sz')
  */
@@ -972,3 +992,82 @@ fs_incompat_renumber (int *ret)
     *ret = 1;
     return 0;
 }
+
+
+/*
+ *
+ */
+
+int
+fs_statistics_list(u_int32_t *host, u_int32_t *part, int *n)
+{
+    u_int32_t data[512];
+    u_int32_t indata;
+    struct ViceIoctl a_params;
+    int i;
+
+    indata = STATISTICS_OPCODE_LIST;
+
+    a_params.in_size  = sizeof(indata);
+    a_params.out_size = sizeof(data);
+    a_params.in       = (char *) &indata;
+    a_params.out      = (char *) data;
+
+    memset (data, 0, sizeof(data));
+
+    if (k_pioctl (NULL, AIOC_STATISTICS , &a_params, 0) == -1)
+	return errno;
+
+    if (data[0] < *n)
+	*n = data[0];
+
+    for (i = 0; i < *n; i++) {
+	host[i] = data[2 * i + 1];
+	part[i] = data[2 * i + 2];
+    }
+
+    return 0;
+}
+
+int
+fs_statistics_entry(u_int32_t host, u_int32_t part, u_int32_t type,
+		    u_int32_t items_slot, u_int32_t *count,
+		    int64_t *items_total, int64_t *total_time)
+{
+    u_int32_t data[160];
+    u_int32_t indata[5];
+    struct ViceIoctl a_params;
+    int i;
+    int j;
+
+    indata[0] = STATISTICS_OPCODE_GETENTRY;
+    indata[1] = host;
+    indata[2] = part;
+    indata[3] = type;
+    indata[4] = items_slot;
+
+    a_params.in_size  = sizeof(indata);
+    a_params.out_size = sizeof(data);
+    a_params.in       = (char *) indata;
+    a_params.out      = (char *) data;
+
+    memset (data, 0, sizeof(data));
+
+    if (k_pioctl (NULL, AIOC_STATISTICS , &a_params, 0) == -1)
+	return errno;
+
+    j = 0;
+    for (i = 0; i < 32; i++) {
+	count[i] = data[j++];
+    }
+    for (i = 0; i < 32; i++) {
+	memcpy(&items_total[i], &data[j], 8);
+	j+=2;
+    }
+    for (i = 0; i < 32; i++) {
+	memcpy(&total_time[i], &data[j], 8);
+	j+=2;
+    }
+
+    return 0;
+}
