@@ -36,7 +36,7 @@
 #include <sl.h>
 #include "appl_locl.h"
 
-RCSID("$Id: pts.c,v 1.50.2.2 2001/07/06 01:40:11 lha Exp $");
+RCSID("$Id: pts.c,v 1.50.2.3 2002/07/11 14:00:41 lha Exp $");
 
 static int help_cmd (int argc, char **argv);
 
@@ -1525,10 +1525,10 @@ main(int argc, char **argv)
     int pos = 0;
     int i;
 
-    set_progname(argv[0]);
+    setprogname(argv[0]);
     tzset();
 
-    method = log_open (get_progname(), "/dev/stderr:notime");
+    method = log_open (getprogname(), "/dev/stderr:notime");
     if (method == NULL)
 	errx (1, "log_open failed");
     cell_init(0, method);
