@@ -35,7 +35,7 @@
 #include <sl.h>
 #include "vos_local.h"
 
-RCSID("$Id: vos_unlock.c,v 1.4 2000/10/03 00:09:39 lha Exp $");
+RCSID("$Id: vos_unlock.c,v 1.4.2.1 2001/11/16 16:57:00 mattiasa Exp $");
 
 /*
  * unlock a volume
@@ -71,6 +71,7 @@ vos_unlock_volume(char *volname)
     const char *host = NULL;
     arlalib_authflags_t auth;
     int error;
+    int32_t dbhost;
     vldbentry vol;
 
     find_db_cell_and_host((const char **)&cell, &host);
@@ -85,11 +86,18 @@ vos_unlock_volume(char *volname)
 
     auth = arlalib_getauthflag(noauth, localauth, 0, 0);
 
-    connvldb = arlalib_getconnbyname(cell, host,
-			  afsvldbport,
-			  VLDB_SERVICE_ID,
-			  auth);
-
+    error = arlalib_getsyncsite(cell, NULL, afsvldbport, 
+				&dbhost, auth);
+    if (error) {
+	fprintf (stderr, "vos_createvolume: arla_getsyncsite: %s\n", 
+	       koerr_gettext(error));
+	return -1;
+    }
+    
+    connvldb = arlalib_getconnbyaddr(cell, dbhost, NULL,
+				     afsvldbport,
+				     VLDB_SERVICE_ID,
+				     auth);
     if(connvldb == NULL) {
 	fprintf(stderr, "can't connect to vldb server %s in cell %s\n",
 		host, cell);
