@@ -36,7 +36,7 @@
 #include <getarg.h>
 #include <arla-version.h>
 
-RCSID("$Id: arla-cli.c,v 1.7 2000/12/04 22:45:19 lha Exp $");
+RCSID("$Id: arla-cli.c,v 1.7.2.3 2002/07/11 14:00:43 lha Exp $");
 
 char *default_log_file = "/dev/stderr";
 char *default_arla_cachedir = ".arlacache";
@@ -318,14 +318,14 @@ print_dir_long (VenusFid *fid, const char *name, void *v)
     strftime (timestr, sizeof(timestr), "%Y-%m-%d", t);
     printf ("%c%c%c%c%c%c%c%c%c%c %2d %6d %6d %8d %s ",
 	    type,
-	    status.UnixModeBits & 0x100 ? 'w' : '-',
-	    status.UnixModeBits & 0x080 ? 'r' : '-',
+	    status.UnixModeBits & 0x100 ? 'r' : '-',
+	    status.UnixModeBits & 0x080 ? 'w' : '-',
 	    status.UnixModeBits & 0x040 ? 'x' : '-',
-	    status.UnixModeBits & 0x020 ? 'w' : '-',
-	    status.UnixModeBits & 0x010 ? 'r' : '-',
+	    status.UnixModeBits & 0x020 ? 'r' : '-',
+	    status.UnixModeBits & 0x010 ? 'w' : '-',
 	    status.UnixModeBits & 0x008 ? 'x' : '-',
-	    status.UnixModeBits & 0x004 ? 'w' : '-',
-	    status.UnixModeBits & 0x002 ? 'r' : '-',
+	    status.UnixModeBits & 0x004 ? 'r' : '-',
+	    status.UnixModeBits & 0x002 ? 'w' : '-',
 	    status.UnixModeBits & 0x001 ? 'x' : '-',
 	    status.LinkCount,
 	    status.Owner,
@@ -687,7 +687,7 @@ main (int argc, char **argv)
     int optind = 0;
     int ret;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (getarg (args, sizeof(args)/sizeof(*args), argc, argv, &optind))
 	usage (1);
