@@ -39,7 +39,7 @@
 #include <parse_units.h>
 #include <getarg.h>
 
-RCSID("$Id: arla.c,v 1.135.2.2 2001/09/14 13:26:31 lha Exp $") ;
+RCSID("$Id: arla.c,v 1.135.2.5 2002/09/07 17:12:01 lha Exp $") ;
 
 enum connected_mode connected_mode = CONNECTED;
 
@@ -74,6 +74,7 @@ struct conf_param {
  */
 
 static struct units size_units[] = {
+    { "G", 1024 * 1024 * 1024 },
     { "M", 1024 * 1024 },
     { "k", 1024 },
     { NULL, 0 }
@@ -131,7 +132,7 @@ read_conffile(char *fname,
 	val = parse_units(v, size_units, NULL);
 	if(val == (unsigned)-1) {
 	    val = strtol(v, &endptr, 0);
-	    if (endptr == v)
+	    if (*endptr != '\0' && !isspace((int)*endptr))
 		fprintf (stderr, "%s:%d: bad value `%s'\n",
 			 fname, lineno, v);
 	}
@@ -205,6 +206,7 @@ int help_flag;
 int recover = 0;
 int dynroot_enable = 0;
 int cm_consistency = 0;
+int fake_stat = 0;
 
 /*
  * These are exported to other modules
@@ -299,6 +301,9 @@ arla_init (int argc, char **argv)
     if (log_file == NULL)
 	log_file = default_log_file;
 
+    if (strcmp(log_file, "syslog") == 0)
+	log_file = "syslog:no-delay";
+
     log_flags = 0;
     if (cpu_usage)
 	log_flags |= LOG_CPU_USAGE;
