@@ -35,7 +35,7 @@
  * The interface for the file-cache.
  */
 
-/* $Id: fcache.h,v 1.72.2.2 2001/10/02 16:13:07 jimmy Exp $ */
+/* $Id: fcache.h,v 1.72.2.3 2002/03/07 15:33:57 lha Exp $ */
 
 #ifndef _FCACHE_H_
 #define _FCACHE_H_
@@ -192,7 +192,8 @@ int
 write_data (FCacheEntry *entry, AFSStoreStatus *status, CredCacheEntry *ce);
 
 int
-truncate_file (FCacheEntry *entry, off_t size, CredCacheEntry *ce);
+truncate_file (FCacheEntry *entry, off_t size,
+	       AFSStoreStatus *status, CredCacheEntry *ce);
 
 int
 write_attr (FCacheEntry *entry, const AFSStoreStatus *status,
