@@ -36,7 +36,7 @@
  */
 
 #include "arla_local.h"
-RCSID("$Id: inter.c,v 1.110.2.3 2001/06/05 01:27:05 ahltorp Exp $") ;
+RCSID("$Id: inter.c,v 1.110.2.5 2002/06/29 04:37:35 lha Exp $") ;
 
 #include <xfs/xfs_message.h>
 
@@ -432,7 +432,8 @@ cm_setattr (VenusFid fid, AFSStoreStatus *attr, CredCacheEntry* ce)
  */
 
 Result
-cm_ftruncate (VenusFid fid, off_t size, CredCacheEntry* ce)
+cm_ftruncate (VenusFid fid, off_t size, AFSStoreStatus *storestatus,
+	      CredCacheEntry* ce)
 {
      FCacheEntry *entry;
      Result ret;
@@ -464,7 +465,7 @@ cm_ftruncate (VenusFid fid, off_t size, CredCacheEntry* ce)
      }
 
      if (checkright (entry, AWRITE, ce)) {
-	  ret.res   = truncate_file (entry, size, ce);
+	  ret.res   = truncate_file (entry, size, storestatus, ce);
 	  ret.error = ret.res;
 
 	  log_operation ("ftruncate (%ld,%lu,%lu,%lu) %lu\n",
@@ -1165,13 +1166,22 @@ cm_rename(VenusFid *old_parent_fid, const char *old_name,
 	    }
 	    
 	    /*
-	     * Lookup the new name, if it exists we need to clear it out.
-	     * XXX Should we check the lnkcount and clear it from fcache ?
+	     * Lookup the new name, if it exists we need to silly
+	     * rename it was just killed on the fileserver.
+	     * XXXDISCO remember mark this node as dead
 	     */
 	    
 	    error = adir_lookup (new_dir, new_name, &old_fid);
-	    if (error == 0)
+	    if (error == 0) {
+		FCacheEntry *old_entry;
+
+		error = fcache_find (&old_entry, old_fid);
+		if (error == 0) {
+		    old_entry->flags.silly = TRUE;
+		    fcache_release (old_entry);
+		}
 		adir_remove (new_dir, new_name);
+	    }
 	    
 	    /*
 	     * Now do the rename, ie create the new name and remove
