@@ -35,7 +35,7 @@
  * The interface to the cache manager.
  */
 
-/* $Id: inter.h,v 1.24 2000/11/28 01:42:15 lha Exp $ */
+/* $Id: inter.h,v 1.24.2.1 2002/03/07 15:34:03 lha Exp $ */
 
 #ifndef _INTER_H_
 #define _INTER_H_
@@ -77,7 +77,8 @@ Result
 cm_setattr (VenusFid fid, AFSStoreStatus *attr, CredCacheEntry *ce);
 
 Result
-cm_ftruncate (VenusFid fid, off_t size, CredCacheEntry *ce);
+cm_ftruncate (VenusFid fid, off_t size, AFSStoreStatus *storestatus,
+	      CredCacheEntry *ce);
 
 Result
 cm_access (VenusFid fid, int mode, CredCacheEntry *ce);
