@@ -32,7 +32,7 @@
  */
 
 #include "arla_local.h"
-RCSID("$Id: messages.c,v 1.231.2.10 2001/10/02 16:13:08 jimmy Exp $");
+RCSID("$Id: messages.c,v 1.231.2.16 2002/08/29 20:04:33 ahltorp Exp $");
 
 #include <xfs/xfs_message.h>
 
@@ -232,8 +232,26 @@ fcacheentry2xfsnode (const VenusFid *fid,
     int i;
 
     memcpy (&node->handle, fid, sizeof(*fid));
-    if (flags & FCACHE2XFSNODE_ATTR)
+    if (flags & FCACHE2XFSNODE_ATTR) {
 	afsstatus2xfs_attr (status, statfid, &node->attr);
+	
+	/* XXX this is wrong */
+	if (fake_stat) {
+	    u_char rights;
+	    
+	    rights = afsrights2xfsrights(status->CallerAccess,
+					 status->FileType,
+					 status->UnixModeBits);
+	    
+	    node->attr.xa_mode &= ~0777;
+	    if (rights & XFS_RIGHT_R)
+		node->attr.xa_mode |= 0444;
+	    if (rights & XFS_RIGHT_W)
+		node->attr.xa_mode |= 0222;
+	    if (rights & XFS_RIGHT_X)
+		node->attr.xa_mode |= 0111;
+	}
+    }
     if (flags & FCACHE2XFSNODE_RIGHT) {
 	node->anonrights = afsrights2xfsrights(status->AnonymousAccess,
 					       status->FileType,
@@ -407,6 +425,7 @@ xfs_message_getroot (int fd, struct xfs_message_getroot *h, u_int size)
 			      &status, &msg.node, ae,
 			      FCACHE2XFSNODE_ALL);
 
+	 msg.node.tokens = res.tokens & ~XFS_DATA_MASK;
 	 msg.header.opcode = XFS_MSG_INSTALLROOT;
 	 h0 = (struct xfs_message_header *)&msg;
 	 h0_len = sizeof(msg);
@@ -571,9 +590,8 @@ xfs_message_putattr (int fd, struct xfs_message_putattr *h, u_int size)
      do {
 	 res.res = 0;
 	 if (XA_VALID_SIZE(&h->attr))
-	     res = cm_ftruncate (*fid, h->attr.xa_size, ce);
-
-	 if (res.res == 0)
+	     res = cm_ftruncate (*fid, h->attr.xa_size, &status, ce);
+	 else
 	     res = cm_setattr(*fid, &status, ce);
 
 	 if (res.res)
@@ -2642,14 +2660,20 @@ token_for_cell (int fd, struct xfs_message_pioctl *h, u_int size,
 		CredCacheEntry *ce)
 {
     struct ClearToken ct;
-    char buf[2048];
-    size_t len;
+    char buf[XFS_MSG_MAX_DATASIZE];
+    size_t len, cell_len;
     char *p = buf;
     u_int32_t tmp;
     krbstruct *kstruct = (krbstruct *)ce->cred_data;
     CREDENTIALS *cred  = &kstruct->c;
     const char *cell = cell_num2name (ce->cell);
 
+    cell_len = strlen(cell);
+
+    len = 4 + cred->ticket_st.length + 4 + sizeof(ct) + 4 + cell_len;
+    if (len > sizeof(buf))
+	return xfs_send_message_wakeup (fd, h->header.sequence_num, EINVAL);
+
     ct.AuthHandle = cred->kvno;
     memcpy (ct.HandShakeKey, cred->session, sizeof(cred->session));
     ct.ViceId         = ce->uid;
@@ -2666,7 +2690,7 @@ token_for_cell (int fd, struct xfs_message_pioctl *h, u_int size,
     p += sizeof(tmp);
     memcpy (p, &ct, sizeof(ct));
     p += sizeof(ct);
-    tmp = strlen(cell);
+    tmp = cell_len;
     memcpy (p, &tmp, sizeof(tmp));
     p += sizeof(tmp);
     strcpy (p, cell);
@@ -2749,9 +2773,10 @@ viocsettok (int fd, struct xfs_message_pioctl *h, u_int size)
     char *t = h->msg;
 
     /* someone probed us */
-    if (h->insize == 0) {
+    if (h->insize == 0)
+	return EINVAL;
+    if (h->insize < 4)
 	return EINVAL;
-    }
 
     /* Get ticket_st */
     memcpy(&sizeof_x, t, sizeof(sizeof_x)) ;
@@ -2759,20 +2784,34 @@ viocsettok (int fd, struct xfs_message_pioctl *h, u_int size)
     arla_warnx (ADEBMSG, "ticket_st has size %d", sizeof_x);
     t += sizeof(sizeof_x) ;
 
+    /* data used + datalen + cleartoken's length field */
+    if ((t - (char *)h->msg) + sizeof_x + 4 > h->insize)
+	return EINVAL;
+    if (sizeof_x > sizeof(c.ticket_st.dat))
+	return EINVAL;
+    
     memcpy(c.ticket_st.dat, t, sizeof_x) ;
     t += sizeof_x ;
-
+    
     /* Get ClearToken */
     memcpy(&sizeof_x, t, sizeof(sizeof_x)) ;
     t += sizeof(sizeof_x) ;
-
+    
+    /* data used + datalen + cell's length field */
+    if ((t - (char *)h->msg) + sizeof_x + 4 > h->insize)
+	return EINVAL;
+    
     memcpy(&ct, t, sizeof_x) ;
     t += sizeof_x ;
 
     /* Get primary cell ? */
     memcpy(&sizeof_x, t, sizeof(sizeof_x)) ;
     t += sizeof(sizeof_x) ;
-
+    
+    /* data used + datalen + cell's length field */
+    if ((t - (char *)h->msg) + sizeof_x + 4 > h->insize)
+	return EINVAL;
+    
     /* Get Cellname */ 
     strncpy(c.realm, t, REALM_SZ) ;
     c.realm[REALM_SZ-1] = '\0' ;
@@ -2851,6 +2890,16 @@ viocconnect(int fd, struct xfs_message_pioctl *h, u_int size)
 
 	ret = tmp;
 
+	/* check permission */
+	switch (tmp) {
+	case CONNMODE_PROBE:
+	    break;
+	default:
+	    if (!all_powerful_p(&h->cred))
+		return EPERM;
+	    break;
+	}
+
 	switch(tmp) {
 	case CONNMODE_PROBE:
 	    switch(connected_mode) {
@@ -2930,6 +2979,9 @@ setrxkcrypt(int fd, struct xfs_message_pioctl *h, u_int size)
 #ifdef KERBEROS
     int error = 0;
 
+    if (!all_powerful_p(&h->cred))
+	return EPERM;
+
     if (h->insize == sizeof(u_int32_t)) {
 	u_int32_t n;
 
@@ -2972,6 +3024,8 @@ vioc_fpriostatus (int fd, struct xfs_message_pioctl *h, u_int size)
     fid.fid.Vnode = fprio->Vnode ;
     fid.fid.Unique = fprio->Unique ;
 
+    if (!all_powerful_p(&h->cred))
+	return EPERM;
 
 #if 0
     switch(fprio->cmd) {
