@@ -35,7 +35,7 @@
 
 #include "arla_local.h"
 
-RCSID("$Id: reconnect.c,v 1.30.2.1 2001/06/04 22:16:39 ahltorp Exp $");
+RCSID("$Id: reconnect.c,v 1.30.2.2 2002/03/07 15:34:08 lha Exp $");
 
 static int reconnect_nonmute(struct vcache *, int, struct timeval);
 static int reconnect_putattr(struct vcache *, struct xfs_attr *);
@@ -1191,7 +1191,11 @@ int reconnect_putattr(struct vcache *vcp, struct xfs_attr *xap)
 #if 0
 /* Ba shier: should we send the file back to server?  */
     if (XA_VALID_SIZE(xap)){
-	res = cm_ftruncate (*fid, xap->xa_size, ce);
+	AFSStoreStatus storestatus;
+	memset(&storestatus, 0, sizeof(storestatus));
+	storestatus.Mask = 0;
+
+	res = cm_ftruncate (*fid, xap->xa_size, &storestatus, ce);
     }  
 #endif
 
