@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 1996, 1997, 1998, 1999 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -14,12 +14,7 @@
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  * 
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the Kungliga Tekniska
- *      Hgskolan and its contributors.
- * 
- * 4. Neither the name of the Institute nor the names of its contributors
+ * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
@@ -42,7 +37,7 @@
 
 #include <config.h>
 
-RCSID("$Id: fdir.c,v 1.2 1999/06/21 01:17:42 assar Exp $") ;
+RCSID("$Id: fdir.c,v 1.9 2000/10/02 22:59:43 lha Exp $") ;
 
 #include <sys/types.h>
 #include <sys/errno.h>
@@ -58,9 +53,10 @@ RCSID("$Id: fdir.c,v 1.2 1999/06/21 01:17:42 assar Exp $") ;
  */
 
 static unsigned
-hashentry (const unsigned char *entry)
+hashentry (const char *sentry)
 {
      int s = 0, h;
+     const unsigned char *entry = (const unsigned char *)sentry;
 
      while (*entry)
 	  s = s * 173 + *entry++;
@@ -163,8 +159,7 @@ find_by_name (DirPage0 *page0,
 static int
 update_fid_by_name (DirPage0 *page0,
 		    const char *name,
-		    const VenusFid *fid,
-		    const VenusFid *dir)
+		    const VenusFid *fid)
 {
     DirEntry *entry = find_entry (page0, name);
 
@@ -172,7 +167,7 @@ update_fid_by_name (DirPage0 *page0,
 	return -1;
 
     entry->fid.Vnode = htonl (fid->fid.Vnode);
-    entry->fid.Vnode = htonl (fid->fid.Unique);
+    entry->fid.Unique = htonl (fid->fid.Unique);
     return 0;
 }
 
@@ -336,7 +331,8 @@ remove_from_page (DirPage0 *page0,
  */
 
 int
-fdir_lookup (fbuf *the_fbuf, VenusFid *dir, const char *name, VenusFid *file)
+fdir_lookup (fbuf *the_fbuf, const VenusFid *dir,
+	     const char *name, VenusFid *file)
 {
      DirPage0 *page0;
      unsigned ind;
@@ -359,15 +355,14 @@ fdir_lookup (fbuf *the_fbuf, VenusFid *dir, const char *name, VenusFid *file)
 int
 fdir_changefid (fbuf *the_fbuf,
 		const char *name,
-		VenusFid *file,
-		VenusFid *dir)
+		const VenusFid *file)
 {
     DirPage0 *page0;
     int ret;
 
     page0 = (DirPage0 *)fbuf_buf(the_fbuf);
     assert (page0);
-    ret = update_fid_by_name (page0, name, file, dir);
+    ret = update_fid_by_name (page0, name, file);
 
     if (ret == 0)
 	return 0;
@@ -400,9 +395,9 @@ fdir_emptyp (fbuf *dir)
 
 int
 fdir_readdir (fbuf *the_fbuf,
-	      void (*func)(VenusFid *, const char *, void *), 
+	      fdir_readdir_func func,
 	      void *arg,
-	      VenusFid *dir)
+	      const VenusFid *dir)
 {
      DirPage0 *page0;
      unsigned i, j;
@@ -524,6 +519,9 @@ fdir_creat (fbuf *dir,
 
     assert (npages == dir->len / AFSDIR_PAGESIZE);
 
+    if (find_entry (page0, name))
+	return EEXIST;
+
     hash_value = hashentry (name);
     next = page0->dheader.hash[hash_value];
 
