@@ -33,7 +33,7 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-RCSID("$Id: agetarg.c,v 1.8.2.3 2001/05/17 07:38:30 lha Exp $");
+RCSID("$Id: agetarg.c,v 1.8.2.4 2002/06/11 14:10:39 ahltorp Exp $");
 #endif
 
 #include <stdio.h>
@@ -478,8 +478,7 @@ agetarg(struct agetargs *args,
 	    usedargs[swcount] = 1;
 	    i += j;
 	    swcount++;
-	} else if(argv[i][0] == '-' &&
-		  (argv[i][1] == '-' || 
+	} else if((argv[i][1] == '-' || 
 		   ((style & AARG_TRANSLONG) && argv[i][1] != 0))) {
 	    int k;
 
