@@ -34,7 +34,7 @@
 #include "ko_locl.h"
 #include <fnmatch.h>
 
-RCSID("$Id: gensysname.c,v 1.35.2.1 2001/09/15 13:33:04 mattiasa Exp $");
+RCSID("$Id: gensysname.c,v 1.35.2.2 2002/07/11 14:00:45 lha Exp $");
 
 typedef int (*test_sysname)(void);
 typedef void (*gen_sysname)(char*, size_t, const char*, 
@@ -180,7 +180,7 @@ printsysname(const char *sysname)
 	printf("%s\n", sysname);
 	break;
     case OUTPUT_C:
-	printf("/* Generated from $Id: gensysname.c,v 1.35.2.1 2001/09/15 13:33:04 mattiasa Exp $ */\n\n");
+	printf("/* Generated from $Id: gensysname.c,v 1.35.2.2 2002/07/11 14:00:45 lha Exp $ */\n\n");
 	printf("#ifdef HAVE_CONFIG_H\n#include <config.h>\n#endif\n");
 	printf("#include <ko.h>\n\n");
 	printf("const char *arla_getsysname(void) { return \"%s\" ; }\n", 
@@ -249,7 +249,7 @@ main(int argc, char **argv)
     int found = 0;
     int optind = 0;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (agetarg (args, argc, argv, &optind, AARG_GNUSTYLE)) 
 	usage();
@@ -261,7 +261,7 @@ main(int argc, char **argv)
 	usage();
 
     if (versionflag)
-	errx(0, "Version: $Id: gensysname.c,v 1.35.2.1 2001/09/15 13:33:04 mattiasa Exp $");
+	errx(0, "Version: $Id: gensysname.c,v 1.35.2.2 2002/07/11 14:00:45 lha Exp $");
 
     if (ccodeflag)
 	output = OUTPUT_C;
