@@ -43,6 +43,7 @@
 #ifdef HAVE_RESOLV_H
 #include <resolv.h>
 #endif
+#include <resolve.h>
 
 #ifdef KERBEROS
 #include <krb.h>
@@ -50,7 +51,7 @@
 
 #include "resolve.h"
 
-RCSID("$Id: kocell.c,v 1.47.2.3 2001/07/09 03:27:48 lha Exp $");
+RCSID("$Id: kocell.c,v 1.47.2.6 2002/10/08 22:59:32 lha Exp $");
 
 #define TRANSARCSYSCONFDIR "/usr/vice/etc"
 #define CELLFILENAME "CellServDB"
@@ -274,7 +275,7 @@ dns_lookup_cell (const char *cell, cell_entry *c)
     struct resource_record *rr;
     int dbnum = 0;
     cell_db_entry dbservers[256];
-    int lowest_ttl;
+    int lowest_ttl = INT_MAX;
     int i;
     struct timeval tv;
 
@@ -300,7 +301,7 @@ dns_lookup_cell (const char *cell, cell_entry *c)
 	    if (dbnum >= sizeof (dbservers) / sizeof(*dbservers)) {
 	        break;
 	    }
-	    if (lowest_ttl > rr->ttl || lowest_ttl == 0)
+	    if (lowest_ttl > rr->ttl)
 		lowest_ttl = rr->ttl;
 	    dbservers[dbnum].name = strdup (mx->domain);
 	    if (dbservers[dbnum].name == NULL)
@@ -322,6 +323,9 @@ dns_lookup_cell (const char *cell, cell_entry *c)
     }
     dns_free_data(r);
 
+    if (lowest_ttl == INT_MAX)
+	lowest_ttl = 0;
+
     /* catch the hosts that didn't fit in additional rr */
     c->timeout = lowest_ttl + tv.tv_sec;
     updatehosts (c, dbnum, dbservers);
@@ -429,21 +433,11 @@ cell_entry *
 cell_new_dynamic (const char *name)
 {
     cell_entry *c;
-    FILE *f;
 
     c = cell_new (name);
     if (c == NULL)
 	return NULL;
     c->expl = "dynamically added cell";
-    f = fopen (SYSCONFDIR "/" CELLFILENAME, "a");
-    if (f == NULL)
-	f = fopen (TRANSARCSYSCONFDIR "/" CELLFILENAME, "a");
-    if (f == NULL) {
-	log_log (cell_log, CDEBWARN,"Cannot open CellServDB for writing");
-	return c;
-    }
-    fprintf (f, ">%s	#dynamically added cell\n", name);
-    fclose (f);
     return c;
 }
 
