@@ -31,7 +31,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: roken.h,v 1.31 2000/10/15 21:12:37 assar Exp $ */
+/* $Id: roken.h,v 1.31.2.2 2002/07/11 13:57:30 lha Exp $ */
 
 #ifndef __ROKEN_H__
 #define __ROKEN_H__
@@ -475,6 +475,14 @@ copyhostent (const struct hostent *h);
 void set_progname(char *argv0);
 const char *get_progname(void);
 
+#ifndef HAVE_SETPROGNAME
+#define setprogname	set_progname
+#endif
+
+#ifndef HAVE_GETPROGNAME
+#define getprogname	get_progname
+#endif
+
 #ifndef F_OK
 #define F_OK 0
 #endif
