@@ -34,7 +34,7 @@
 #include <config.h>
 #include "roken.h"
 
-RCSID("$Id: sked.c,v 1.26 2000/12/29 20:21:30 tol Exp $");
+RCSID("$Id: sked.c,v 1.26.2.1 2002/07/11 14:00:48 lha Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -777,9 +777,9 @@ main (int argc, char **argv)
     Log_method *method;
     char *log_file = "/dev/stderr";
     
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
-    method = log_open (get_progname(), log_file);
+    method = log_open (getprogname(), log_file);
     if (method == NULL)
 	errx (1, "log_open failed");
     
