@@ -66,7 +66,7 @@
 #include "ptserver.h"
 #include "pts.ss.h"
 
-RCSID("$Id: ptserver.c,v 1.36 2000/12/29 19:55:21 tol Exp $");
+RCSID("$Id: ptserver.c,v 1.36.2.1 2002/07/11 14:00:50 lha Exp $");
 
 static struct rx_service *prservice;
 
@@ -896,7 +896,7 @@ main(int argc, char **argv)
     int optind = 0;
     int ret;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (agetarg (args, argc, argv, &optind, AARG_AFSSTYLE)) {
 	usage (1);
@@ -913,7 +913,7 @@ main(int argc, char **argv)
     if (do_help)
 	usage(0);
 
-    pr_method = log_open (get_progname(), log_file);
+    pr_method = log_open (getprogname(), log_file);
     if (pr_method == NULL)
 	errx (1, "log_open failed");
 
