@@ -33,7 +33,7 @@
 
 #include "vldb_locl.h"
 
-RCSID("$Id: vldbserver.c,v 1.33 2001/01/01 20:42:58 lha Exp $");
+RCSID("$Id: vldbserver.c,v 1.33.2.1 2002/07/11 14:00:51 lha Exp $");
 
 static void make_vldb_from_vl(struct vldbentry *vldb_entry,
 			      struct disk_vlentry *vl_entry);
@@ -761,7 +761,7 @@ main(int argc, char **argv)
     int optind = 0;
     int ret;
     
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (agetarg (args, argc, argv, &optind, AARG_AFSSTYLE)) {
 	usage ();
@@ -787,7 +787,7 @@ main(int argc, char **argv)
 	return 0;
     }
 	
-    method = log_open (get_progname(), log_file);
+    method = log_open (getprogname(), log_file);
     if (method == NULL)
 	errx (1, "log_open failed");
     cell_init(0, method);
