@@ -44,7 +44,7 @@
 #include "config.h"
 #include "roken.h"
 
-RCSID ("$Id: rxdebug.c,v 1.7.2.3 2001/09/20 23:38:17 mattiasa Exp $");
+RCSID ("$Id: rxdebug.c,v 1.7.2.6 2002/11/12 13:23:28 mattiasa Exp $");
 
 #define	TIMEOUT	    20
 
@@ -394,9 +394,6 @@ MainCommand (void)
 	exit(1);
     }
 
-    if ((tstats.version < RX_DEBUGI_VERSION_MINIMUM) ||
-	(tstats.version > RX_DEBUGI_VERSION))
-	tstats.version = RX_DEBUGI_VERSION_MINIMUM-1;
     withSecStats = (tstats.version >= RX_DEBUGI_VERSION_W_SECSTATS);
     withAllConn = (tstats.version >= RX_DEBUGI_VERSION_W_GETALLCONN);
     withRxStats = (tstats.version >= RX_DEBUGI_VERSION_W_RXSTATS);
@@ -414,17 +411,15 @@ MainCommand (void)
 	printf("%ld calls waiting for a thread\n",
 	       (long)ntohl(tstats.nWaiting));
     
-    if (rxstats) {
-	if (!withRxStats) {
-	noRxStats:
-	    withRxStats = 0;
+    if (rxstats && withRxStats) {
+	if(!withRxStats) {
 	    fprintf (stderr, "WARNING: Server doens't support "
 		     "retrieval of Rx statistics\n");
 	} else {
 	    struct rx_stats rxstats;
 	    int i;
 	    long *lp;
-	    
+	
 	    bzero (&rxstats, sizeof(rxstats));
 	    tin.type = htonl(RX_DEBUGI_RXSTATS);
 	    tin.index = 0;
@@ -435,22 +430,26 @@ MainCommand (void)
 		printf("rxstats call failed with code %d\n", code);
 		exit(1);
 	    }
-	    if (code != sizeof(rxstats)) {
-		if ((code == sizeof(tin)) &&
-		    (ntohl(((struct rx_debugIn *)(&rxstats))->type) ==
-		     RX_DEBUGI_BADTYPE)) goto noRxStats;
-		fprintf (stderr, "WARNING: returned Rx statistics of "
-			 "unexpected size (got %d)\n",
-			code);
-		/* handle other versions?... */
+
+	    if ((code == sizeof(tin)) &&
+		(ntohl(((struct rx_debugIn *)(&rxstats))->type) ==
+		 RX_DEBUGI_BADTYPE)) {
+		fprintf (stderr, "WARNING: Server doens't support "
+			 "retrieval of Rx statistics\n");
+	    } else {
+		if  (code != sizeof(rxstats)) {
+		    /* handle other versions?... */
+		    fprintf (stderr, "WARNING: returned Rx statistics of "
+			     "unexpected size (got %d)\n",
+			     code);
+		}
+		/* Since its all longs convert to host order with a loop. */
+		lp = (long *)&rxstats;
+		for (i=0; i<sizeof(rxstats)/sizeof(int); i++,lp++)
+		    *lp = ntohl(*lp);
+		
+		rx_PrintTheseStats (stdout, &rxstats, sizeof(rxstats));
 	    }
-	    
-	    /* Since its all longs convert to host order with a loop. */
-	    lp = (long *)&rxstats;
-	    for (i=0; i<sizeof(rxstats)/sizeof(int); i++,lp++)
-		*lp = ntohl(*lp);
-	    
-	    rx_PrintTheseStats (stdout, &rxstats, sizeof(rxstats));
 	}
     }
     
@@ -459,11 +458,7 @@ MainCommand (void)
     
     tin.type = htonl(RX_DEBUGI_GETCONN);
     if (allconns) {
-	if (!withAllConn) 
-	    fprintf (stderr, "WARNING: Server doesn't support retrieval of "
-		     "all connections,\n"
-		     "getting only interesting instead.\n");
-	else tin.type = htonl(RX_DEBUGI_GETALLCONN);
+	tin.type = htonl(RX_DEBUGI_GETALLCONN);
     }
     
     if (onlyServer) printf ("Showing only server connections\n");
@@ -591,10 +586,10 @@ MainCommand (void)
 			    ((u_long)ntohl(tconn.secStats.expires) -
 			     time(0)) / 3600.0);
 		if (!(flags & 1)) {
-		    printf ("\n  Received %ld bytes in %ld packets\n", 
+		    printf ("\n  Received %lu bytes in %lu packets\n", 
 			    (long)ntohl(tconn.secStats.bytesReceived),
 			    (long)ntohl(tconn.secStats.packetsReceived));
-		    printf ("  Sent %ld bytes in %ld packets\n", 
+		    printf ("  Sent %lu bytes in %lu packets\n", 
 			    (long)ntohl(tconn.secStats.bytesSent),
 			    (long)ntohl(tconn.secStats.packetsSent));
 		} else
