@@ -55,7 +55,7 @@
 #define MAP_FAILED ((void *)-1)
 #endif
 
-RCSID("$Id: append-over-page.c,v 1.3 2000/10/03 00:33:07 lha Exp $");
+RCSID("$Id: append-over-page.c,v 1.3.2.1 2002/07/11 14:00:52 lha Exp $");
 
 static char long_buf[] =
 "1000\n"
@@ -971,7 +971,7 @@ main(int argc, char **argv)
 {
     const char *file = "blaha";
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
     if (argc != 1 && argc != 2)
 	errx (1, "usage: %s [file]", argv[0]);
     if (argc == 2)
