@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: create-remove.c,v 1.2 2000/10/03 00:33:28 lha Exp $");
+RCSID("$Id: create-remove.c,v 1.2.2.1 2002/07/11 14:00:55 lha Exp $");
 #endif
 
 static int
@@ -118,7 +118,7 @@ main(int argc, char **argv)
     char *ptr;
     int count;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (argc != 3)
 	usage (1);
