@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: kill-softer.c,v 1.10 2000/10/03 00:34:15 lha Exp $");
+RCSID("$Id: kill-softer.c,v 1.10.2.1 2002/07/11 14:01:02 lha Exp $");
 #endif
 
 static FILE *verbose;
@@ -177,7 +177,7 @@ kill_dir (const char *dirname)
 int
 main(int argc, char **argv)
 {
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     verbose = fdopen (4, "w");
     if (verbose == NULL) {
