@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: kill-softly.c,v 1.6 2000/10/03 00:34:20 lha Exp $");
+RCSID("$Id: kill-softly.c,v 1.6.2.1 2002/07/11 14:01:02 lha Exp $");
 #endif
 
 struct entry {
@@ -154,7 +154,7 @@ kill_dir (const char *dirname)
 int
 main(int argc, char **argv)
 {
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (argc != 2)
 	errx (1, "usage: %s directory", argv[0]);
