@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: large-dir.c,v 1.7 2000/10/03 00:34:31 lha Exp $");
+RCSID("$Id: large-dir.c,v 1.7.2.1 2002/07/11 14:01:03 lha Exp $");
 #endif
 
 static int
@@ -146,7 +146,7 @@ main(int argc, char **argv)
     char *ptr;
     int count;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (argc != 3)
 	usage (1);
