@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: large-dir3.c,v 1.3 2000/10/03 00:34:42 lha Exp $");
+RCSID("$Id: large-dir3.c,v 1.3.2.1 2002/07/11 14:01:04 lha Exp $");
 #endif
 
 static int
@@ -113,7 +113,7 @@ main(int argc, char **argv)
     char *ptr;
     int count;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (argc != 3)
 	usage (1);
