@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: mmap-and-read.c,v 1.12 2000/12/18 04:03:51 assar Exp $");
+RCSID("$Id: mmap-and-read.c,v 1.12.2.1 2002/07/11 14:01:05 lha Exp $");
 #endif
 
 #ifndef MAP_FAILED
@@ -150,7 +150,7 @@ int
 main (int argc, char **argv)
 {
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     srand (time(NULL));
 
