@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: mmap-vs-read.c,v 1.5 2000/10/03 00:35:03 lha Exp $");
+RCSID("$Id: mmap-vs-read.c,v 1.5.2.1 2002/07/11 14:01:08 lha Exp $");
 #endif
 
 static int debug = 0;
@@ -154,7 +154,7 @@ do_test (int randomp)
 int
 main (int argc, char **argv)
 {
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (argc != 1)
 	debug = 1;
