@@ -48,7 +48,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: read-vs-mmap2.c,v 1.8 2000/10/03 00:35:24 lha Exp $");
+RCSID("$Id: read-vs-mmap2.c,v 1.8.2.1 2002/07/11 14:01:10 lha Exp $");
 #endif
 
 static void
@@ -113,7 +113,7 @@ main (int argc, char **argv)
     void *mmap_buf;
     int fd;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     srand (time(NULL));
 
