@@ -49,7 +49,7 @@
 #include <roken.h>
 
 #ifdef RCSID
-RCSID("$Id: readdir-vs-lstat.c,v 1.11 2000/10/03 00:35:34 lha Exp $");
+RCSID("$Id: readdir-vs-lstat.c,v 1.11.2.1 2002/07/11 14:01:11 lha Exp $");
 #endif
 
 static int
@@ -92,7 +92,7 @@ main(int argc, char **argv)
 {
     char *name = ".";
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     if (argc > 2)
 	usage (1);
