@@ -51,7 +51,7 @@
 
 #include <err.h>
 
-RCSID("$Id: rename5.c,v 1.3 2000/10/03 00:35:44 lha Exp $");
+RCSID("$Id: rename5.c,v 1.3.2.1 2002/07/11 14:01:12 lha Exp $");
 
 static void
 emkdir (const char *path, mode_t mode)
@@ -87,7 +87,7 @@ main(int argc, char **argv)
     int ret;
     struct stat old_sb, new_sb, dot_sb;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
     emkdir ("old_parent", 0777);
     emkdir ("new_parent", 0777);
     emkdir ("old_parent/victim", 0777);
