@@ -49,7 +49,7 @@
 #include <kafs.h>
 
 #ifdef RCSID
-RCSID("$Id: test-parallel2.c,v 1.2 2000/10/03 00:36:10 lha Exp $");
+RCSID("$Id: test-parallel2.c,v 1.2.2.1 2002/07/11 14:01:16 lha Exp $");
 #endif
 
 #define WORKER_TIMES 1000
@@ -162,7 +162,7 @@ main(int argc, char **argv)
 {
     int i, ret;
     
-    set_progname (argv[0]);
+    setprogname (argv[0]);
 
     for (i = 0; i < NUM_WORKER ; i++) {
 	int ret;
