@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1998 - 2000 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden). 
  * All rights reserved. 
  *
@@ -14,12 +14,7 @@
  *    notice, this list of conditions and the following disclaimer in the 
  *    documentation and/or other materials provided with the distribution. 
  *
- * 3. All advertising materials mentioning features or use of this software 
- *    must display the following acknowledgement: 
- *      This product includes software developed by Kungliga Tekniska 
- *      Hgskolan and its contributors. 
- *
- * 4. Neither the name of the Institute nor the names of its contributors 
+ * 3. Neither the name of the Institute nor the names of its contributors 
  *    may be used to endorse or promote products derived from this software 
  *    without specific prior written permission. 
  *
@@ -36,7 +31,7 @@
  * SUCH DAMAGE. 
  */
 
-/* $Id: mount_locl.h,v 1.5 1998/10/31 15:17:11 lha Exp $ */
+/* $Id: mount_locl.h,v 1.8 2000/11/02 05:06:24 assar Exp $ */
 
 #ifndef __mount_locl_h__
 #define __mount_locl_h__
@@ -83,10 +78,6 @@
 
 #define MOUNT_XFS MOUNT_PC
 
-#elif defined(__NetBSD__) || defined(__OpenBSD__)
-
-#define MOUNT_XFS "xfs"
-
 #endif
 
 #if defined(HAVE_OPTRESET) && !defined(HAVE_OPTRESET_DECLARATION)
