@@ -34,7 +34,7 @@
 
 #include "mount_locl.h"
 
-RCSID("$Id: mount_xfs.c,v 1.14 2000/11/02 05:04:33 assar Exp $");
+RCSID("$Id: mount_xfs.c,v 1.14.2.1 2002/07/11 14:01:22 lha Exp $");
 
 static const struct mntopt mopts[] = {
     MOPT_STDOPTS,
@@ -62,7 +62,7 @@ main(int argc, char **argv)
 #ifdef HAVE_OPTRESET
     optreset = 1;
 #endif
-    set_progname(argv[0]);
+    setprogname(argv[0]);
     while ((ch = getopt(argc, argv, "o:F:")) != -1)
 	switch (ch) {
 	case 'o':
