@@ -33,7 +33,7 @@
 
 #include "mount_locl.h"
 
-RCSID("$Id: umount_xfs.c,v 1.6 2000/10/02 23:34:07 lha Exp $");
+RCSID("$Id: umount_xfs.c,v 1.6.2.1 2002/07/11 14:01:22 lha Exp $");
 
 static void
 usage(void)
@@ -47,7 +47,7 @@ main(int argc, char **argv)
 {
     int force = 0;
 
-    set_progname (argv[0]);
+    setprogname (argv[0]);
     if (argc != 2 && argc != 3)
 	usage();
 
