@@ -31,7 +31,7 @@
  * SUCH DAMAGE.
  */
 
-/* 	$Id: xfs_node.h,v 1.22 2000/10/02 23:34:44 lha Exp $	 */
+/* 	$Id: xfs_node.h,v 1.22.2.3 2002/08/14 19:17:57 lha Exp $	 */
 
 #ifndef _xfs_xnode_h
 #define _xfs_xnode_h
@@ -41,9 +41,9 @@
 #if defined(_KERNEL) || !defined(__OpenBSD__)
 #include <sys/vnode.h>
 #endif
-#ifdef __NetBSD__
+#ifdef HAVE_KERNEL_LF_ADVLOCK
 #include <sys/lockf.h>
-#endif /* __NetBSD__ */
+#endif
 
 #include <xfs/xfs_attr.h>
 #include <xfs/xfs_message.h>
@@ -69,8 +69,8 @@ struct xfs_node {
 #else
     int vnlocks;
 #endif
-#ifdef __NetBSD__
-    struct   lockf *i_lockf;
+#ifdef HAVE_KERNEL_LF_ADVLOCK
+    struct   lockf *lockf;
 #endif
     struct ucred *cred;
 };
