@@ -35,7 +35,7 @@
 #include <xfs/xfs_common.h>
 #include <xfs/xfs_deb.h>
 
-RCSID("$Id: xfs_common-bsd.c,v 1.16 2000/10/02 23:31:37 lha Exp $");
+RCSID("$Id: xfs_common-bsd.c,v 1.16.2.1 2001/04/27 23:42:59 mattiasa Exp $");
 
 #ifdef MALLOC_DEFINE
 MALLOC_DEFINE(M_XFS, "xfs", "xfs buffer");
@@ -77,15 +77,6 @@ xfs_suser(struct proc *p)
 #endif
 }
 
-#ifndef HAVE_KERNEL_MEMCPY
-void *
-memcpy (void *s1, const void *s2, size_t n)
-{
-    bcopy (s2, s1, n);
-    return s1;
-}
-#endif
-
 /*
  * Print a `dev_t' in some readable format
  */
