@@ -39,7 +39,7 @@
 #include <xfs/xfs_dev.h>
 #include <xfs/xfs_deb.h>
 
-RCSID("$Id: xfs_dev-common.c,v 1.44.2.1 2001/07/15 03:55:37 assar Exp $");
+RCSID("$Id: xfs_dev-common.c,v 1.44.2.2 2002/07/01 00:07:13 lha Exp $");
 
 struct xfs_channel xfs_channel[NXFS];
 
@@ -366,7 +366,7 @@ xfs_message_send(int fd, struct xfs_message_header * message, u_int size)
 #error what is your exit named ?
 #endif
 
-#if defined(HAVE_STRUCT_PROC_P_SIGMASK) || defined(HAVE_STRUCT_PROC_P_SIGCTX)
+#if defined(HAVE_STRUCT_PROC_P_SIGMASK) || defined(HAVE_STRUCT_PROC_P_SIGCTX) || defined(HAVE_STRUCT_PROC_P_SIGWAITMASK) || defined(__osf__)
 static void
 xfs_block_sigset (sigset_t *sigset)
 {
@@ -374,14 +374,17 @@ xfs_block_sigset (sigset_t *sigset)
     __sigaddset(sigset, SIGIO);
     __sigaddset(sigset, SIGALRM);
     __sigaddset(sigset, SIGVTALRM);
+    __sigaddset(sigset, SIGCHLD);
 #elif defined(SIGADDSET)
     SIGADDSET(*sigset, SIGIO);
     SIGADDSET(*sigset, SIGALRM);
     SIGADDSET(*sigset, SIGVTALRM);
+    SIGADDSET(*sigset, SIGCHLD);
 #else
     *sigset |= sigmask(SIGIO);
     *sigset |= sigmask(SIGALRM);
     *sigset |= sigmask(SIGVTALRM);
+    *sigset |= sigmask(SIGCHLD);
 #endif /* __sigaddset */
 }
 #endif
@@ -446,8 +449,9 @@ xfs_message_rpc(int fd, struct xfs_message_header * message, u_int size,
     }
 
     /*
-     * Remove SIGIO from the sigmask so no IO will
-     * wake us up from tsleep()
+     * Remove signals from the sigmask so no IO will wake us up from
+     * tsleep(). We don't want to wake up from since program (emacs,
+     * bash & co can't handle them.
      */
 
 #ifdef HAVE_STRUCT_PROC_P_SIGMASK
@@ -461,14 +465,11 @@ xfs_message_rpc(int fd, struct xfs_message_header * message, u_int size,
 #elif defined(HAVE_STRUCT_PROC_P_SIGWAITMASK)
     /* OSF 4.0 */
     oldsigmask = proc->p_sigwaitmask;
-    sigaddset(&proc->p_sigwaitmask, SIGIO);
-    sigaddset(&proc->p_sigwaitmask, SIGALRM);
-    sigaddset(&proc->p_sigwaitmask, SIGVTALRM);
+    xfs_block_sigset (&proc->p_sigwaitmask);
 #elif defined(__osf__)
+    /* OSF 5.0 */
     oldsigmask = u.u_sigmask;
-    sigaddset(&u.u_sigmask, SIGIO);
-    sigaddset(&u.u_sigmask, SIGALRM);
-    sigaddset(&u.u_sigmask, SIGVTALRM);
+    xfs_block_sigset (&u.u_sigmask);
 #endif
 
     /*
