@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  *
@@ -37,7 +37,7 @@
 #include <xfs/xfs_deb.h>
 #include <xfs/xfs_vnodeops.h>
 
-RCSID("$Id: xfs_node-bsd.c,v 1.47.2.4 2001/09/17 01:57:20 lha Exp $");
+RCSID("$Id: xfs_node-bsd.c,v 1.47.2.6 2002/05/16 21:21:33 lha Exp $");
 
 extern vop_t **xfs_vnodeop_p;
 
@@ -220,7 +220,17 @@ free_all_xfs_nodes(struct xfs *xfsp, int flags, int unmountp)
 #ifdef HAVE_KERNEL_VFS_DEALLOCATE_SYNCVNODE
 	    vfs_deallocate_syncvnode(mp);
 #else
+	    /* 
+	     * FreeBSD and OpenBSD uses diffrent semantics,
+	     * FreeBSD have does vrele, and OpenBSD does vgone.
+	     */
+#if defined(__OpenBSD__)
+	    vgone(mp->mnt_syncer);
+#elif defined(__FreeBSD__)
 	    vrele(mp->mnt_syncer);
+#else
+#error what os do you use ?
+#endif
 	    mp->mnt_syncer = NULL;
 #endif
 	}
@@ -272,13 +282,20 @@ xfs_node_find(struct xfs *xfsp, xfs_handle *handlep)
      *       on FreeBSD once.
      */
 
-    for(t = XFS_TO_VFS(xfsp)->mnt_vnodelist.lh_first;
-	t != NULL; 
-	t = t->v_mntvnodes.le_next) {
+/* FreeBSD 4.5 and above did rename mnt_vnodelist to mnt_nvnodelist */
+#ifdef HAVE_STRUCT_MOUNT_MNT_NVNODELIST
+    TAILQ_FOREACH(t, &XFS_TO_VFS(xfsp)->mnt_nvnodelist, v_nmntvnodes) {
 	xn = VNODE_TO_XNODE(t);
 	if (xn && xfs_handle_eq(&xn->handle, handlep))
 	    break;
     }
+#else
+    LIST_FOREACH(t, &XFS_TO_VFS(xfsp)->mnt_vnodelist, v_mntvnodes) {
+	xn = VNODE_TO_XNODE(t);
+	if (xn && xfs_handle_eq(&xn->handle, handlep))
+	    break;
+    }
+#endif
 
     if (t != NULL)
 	return xn;
