@@ -51,7 +51,7 @@
 #include <vm/vnode_pager.h>
 #endif
 
-RCSID("$Id: xfs_vnodeops-bsd.c,v 1.87.2.4 2001/07/26 19:51:44 lha Exp $");
+RCSID("$Id: xfs_vnodeops-bsd.c,v 1.87.2.12 2002/12/03 17:04:39 lha Exp $");
 
 /*
  * vnode functions
@@ -639,7 +639,7 @@ xfs_symlink(struct vop_symlink_args * ap)
 
     if (error == 0) {
 	error = xfs_lookup_common(dvp, cnp, vpp);
-#if (!defined(__FreeBSD__) || __FreeBSD_version < 400012) && (!defined(__NetBSD__) || __NetBSD_Version__ < 105240000) && (!defined(__OpenBSD__) || OpenBSD < 200107)
+#if (!defined(__FreeBSD__) || __FreeBSD_version < 400012) && (!defined(__NetBSD__) || __NetBSD_Version__ < 105240000) && (!defined(__OpenBSD__) || OpenBSD <= 200211)
 	if (error == 0)
 	    vput (*vpp);
 #endif
@@ -960,12 +960,11 @@ xfs_putpages (struct vop_putpages_args *ap)
         IN int *rtvals;
         IN vm_ooffset_t offset;
      */
-    /* NetBSD UBC
-       IN struct vnode *vp;
-       IN vm_page_t *m;
-       IN int count;
-       IN int flags;
-       IN int *rtvals;
+    /* NetBSD UBC (>= 1.5Y)
+	IN struct vnode *vp;
+	IN voff_t offlo;
+	IN voff_t offhi;
+	IN int flags;
     */
 {
     struct vnode *vp    = ap->a_vp;
@@ -975,14 +974,21 @@ xfs_putpages (struct vop_putpages_args *ap)
 
     XFSDEB(XDEBVNOPS, ("xfs_putpages\n"));
 
+    if (t == NULL)
+	return 0;
+
     xn->flags |= XFS_DATA_DIRTY;
 
 #ifdef HAVE_STRUCT_VOP_PUTPAGES_ARGS_A_SYNC /* FreeBSD-style */
     return VOP_PUTPAGES(t, ap->a_m, ap->a_count, ap->a_sync, ap->a_rtvals,
 			ap->a_offset);
 #else /* NetBSD-style */
+#if defined(__NetBSD__) && __NetBSD_Version__  >= 105250000 
+    return VOP_PUTPAGES(t, ap->a_offlo, ap->a_offhi, ap->a_flags);
+#else
     return VOP_PUTPAGES(t, ap->a_m, ap->a_count, ap->a_flags, ap->a_rtvals);
 #endif
+#endif /* HAVE_STRUCT_VOP_PUTPAGES_ARGS_A_SYNC */
 }
 #endif /* HAVE_VOP_PUTPAGES */
 
@@ -1028,10 +1034,9 @@ xfs_print (struct vnode *vp)
 }
 #endif
 
-#if 0
 #ifdef HAVE_VOP_ADVLOCK
 static int
-xfs_advlock(void *v)
+xfs_advlock(struct vop_advlock_args *v)
 {
     struct vop_advlock_args /* {
 	struct vnode *a_vp;
@@ -1040,14 +1045,13 @@ xfs_advlock(void *v)
 	struct flock *a_fl;
 	int  a_flags;
     } */ *ap = v;
-
+#if 0
     struct xfs_node *xn = VNODE_TO_XNODE(ap->a_vp);
     int ret;
     xfs_locktype_t locktype;
 
 /*     if (XFS_TOKEN_GOT(xn,  */
 
-#if 0
     if (ap->a_fl.l_start != 0 ||
 	ap->a_fl.l_end != 0)
 	printf ("WARN: someone is trying byte-range locking\n");
@@ -1060,12 +1064,15 @@ xfs_advlock(void *v)
     ret = xfs_advlock_common (xn, );
 
     return ret;
+#elif defined(HAVE_KERNEL_LF_ADVLOCK) && !defined(__OpenBSD__) && !defined(__APPLE__)
+    struct xfs_node *xn = VNODE_TO_XNODE(ap->a_vp);
+ 
+    return lf_advlock(ap, &xn->lockf, xn->attr.va_size);
 #else
-    return 0;
-#endif 			      
+     return EOPNOTSUPP;
+#endif
 }
 #endif /* HAVE_VOP_ADVOCK */
-#endif
 
 #ifdef HAVE_VOP_REVOKE
 static int
@@ -1104,6 +1111,10 @@ xfs_pagein(struct vop_pagein_args *ap)
 
     ret = VOP_READ(ap->a_vp, &uio, 0, ap->a_cred);
 
+    /* Zero out rest of last page if there wasn't enough data in the file */
+    if (ret == 0 && uio.uio_resid > 0)
+	bzero(iov.iov_base, uio.uio_resid);
+    
     kernel_upl_unmap(kernel_map, ap->a_pl);
 
     if (ret) {
@@ -1339,11 +1350,9 @@ static struct vnodeopv_entry_desc xfs_vnodeop_entries[] = {
 #ifdef HAVE_VOP_PRINT
     {&vop_print_desc, (vop_t *) xfs_print}, 
 #endif
-#if 0
 #ifdef HAVE_VOP_ADVLOCK
     {&vop_advlock_desc, (vop_t *) xfs_advlock },
 #endif
-#endif
 #ifdef HAVE_VOP_PAGEIN
     {&vop_pagein_desc, (vop_t *) xfs_pagein },
 #endif
