@@ -44,7 +44,26 @@
 #include <xfs/xfs_syscalls.h>
 #include <xfs/xfs_vnodeops.h>
 
-RCSID("$Id: xfs_vnodeops-common.c,v 1.66.2.2 2001/07/16 10:10:44 lha Exp $");
+RCSID("$Id: xfs_vnodeops-common.c,v 1.66.2.5 2002/09/10 17:58:08 map Exp $");
+
+static void
+xfs_handle_stale(struct xfs_node *xn)
+{
+    struct vnode *vp = XNODE_TO_VNODE(xn);
+
+    if ((xn->flags & XFS_STALE) == 0)
+	return;
+
+#if __APPLE__
+    if (UBCISVALID(vp) && !ubc_isinuse(vp, 1)) {
+	xn->flags &= ~XFS_STALE;
+	ubc_setsize(vp, 0);
+	XFS_TOKEN_CLEAR(xn, ~0,
+			XFS_OPEN_MASK | XFS_ATTR_MASK |
+			XFS_DATA_MASK | XFS_LOCK_MASK);
+    }
+#endif
+}
 
 int
 xfs_open_valid(struct vnode *vp, struct ucred *cred, struct proc *p,
@@ -56,6 +75,8 @@ xfs_open_valid(struct vnode *vp, struct ucred *cred, struct proc *p,
 
     XFSDEB(XDEBVFOPS, ("xfs_open_valid\n"));
 
+    xfs_handle_stale(xn);
+
     do {
 	if (!XFS_TOKEN_GOT(xn, tok)) {
 	    struct xfs_message_open msg;
@@ -314,10 +335,6 @@ xfs_read_common(struct vnode *vp, struct uio *uio, int ioflag,
 	xfs_vfs_readlock(t, xfs_uio_to_proc(uio));
 	xfs_vop_read(t, uio, ioflag, cred, error);
 	xfs_vfs_unlock(t, xfs_uio_to_proc(uio));
-
-	if (uio->uio_iovcnt && uio->uio_iov[0].iov_len > 0)
-	    XFSDEB(XDEBVNOPS, ("xfs_read: byte: %d\n",
-			       ((char*)uio->uio_iov[0].iov_base)[0]));
     }
 
     XFSDEB(XDEBVNOPS, ("xfs_read offset: %lu resid: %d\n",
@@ -351,6 +368,7 @@ xfs_write_common(struct vnode *vp, struct uio *uiop, int ioflag,
 
 	if (error2 == 0) {
 	    xn->attr.va_size  = sub_attr.va_size;
+	    xn->attr.va_bytes = sub_attr.va_size;
 	    xn->attr.va_mtime = sub_attr.va_mtime;
 	    xfs_set_vp_size(vp, sub_attr.va_size);
 	}
@@ -912,6 +930,7 @@ xfs_inactive_common(struct vnode *vp, struct proc *p)
     error = xfs_fsync_common(vp, xn->cred, /* XXX */ 0, p);
     if (error) {
 	printf ("xfs_inactive: failed writing back data: %d\n", error);
+	xn->flags &= ~XFS_DATA_DIRTY;
     }
 
 #ifndef __osf__
