@@ -31,6 +31,8 @@
  * SUCH DAMAGE.
  */
 
+#include <arla-version.h>
+
 #include <xfs/xfs_locl.h>
 #include <xfs/xfs_message.h>
 #include <xfs/xfs_fs.h>
@@ -39,7 +41,7 @@
 #include <xfs/xfs_deb.h>
 #include <xfs/xfs_wrap.h>
 
-RCSID("$Id: xfs_wrap-bsd.c,v 1.33 2000/10/02 23:33:47 lha Exp $");
+RCSID("$Id: xfs_wrap-bsd.c,v 1.33.2.1 2002/09/30 20:38:14 lha Exp $");
 
 int xfs_dev_major;
 
@@ -205,7 +207,9 @@ static struct lkm_dev _module = {
 #elif defined(__FreeBSD__)
 MOD_DEV(xfs,LM_DT_CHAR,-1,&xfs_dev);
 #else
-#if !defined(__APPLE__)
+#if __NetBSD_Version__ >= 106080000
+MOD_DEV("xfs_mod","xfs_mod", NULL, -1, &xfs_dev, -1)
+#elif !defined(__APPLE__)
 MOD_DEV("xfs_mod",LM_DT_CHAR,-1,&xfs_dev)
 #endif
 #endif
@@ -302,8 +306,14 @@ xfs_mod(struct lkm_table * lkmtp,
     }
     ret = lkmdispatch(lkmtp, cmd);
     if(cmd == LKM_E_LOAD) {
-	xfs_dev_major = _module.lkm_offset;
-	printf ("xfs: cdev: %d, syscall: %d\n",
+#if __NetBSD_Version__ >= 106080000
+	xfs_dev_major = _module.lkm_cdevmaj;
+#else
+ 	xfs_dev_major = _module.lkm_offset;
+#endif
+	printf ("xfs (%s): "
+		"using cdev: %d, syscall: %d\n",
+		arla_version,
 		xfs_dev_major, xfs_syscall_num);
     }
     return ret;
