@@ -31,7 +31,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: xfs_message.h,v 1.44 2000/11/15 08:36:45 lha Exp $ */
+/* $Id: xfs_message.h,v 1.44.2.2 2002/08/13 15:12:30 lha Exp $ */
 
 #ifndef _xmsg_h
 #define _xmsg_h
@@ -133,6 +133,7 @@ typedef struct xfs_cache_handle {
 #define XFS_ATTR_DIRTY	0x0002
 #define XFS_AFSDIR	0x0004
 #define XFS_STALE	0x0008
+#define XFS_XDELETED	0x0010
 
 /* Are necessary tokens available? */
 #define XFS_TOKEN_GOT(xn, tok)		((xn)->tokens & (tok))
@@ -420,6 +421,8 @@ struct xfs_message_rename {
   struct xfs_cred cred;
 };
 
+#define XFS_MSG_MAX_DATASIZE	2048
+
 /* XFS_MSG_PIOCTL */
 struct xfs_message_pioctl {
   struct xfs_message_header header;
@@ -428,7 +431,7 @@ struct xfs_message_pioctl {
   xfs_cred cred;
   u_int32_t insize;
   u_int32_t outsize;
-  char msg[2048] ;    /* XXX */
+  char msg[XFS_MSG_MAX_DATASIZE];
   xfs_handle handle;
 };
 
@@ -440,7 +443,7 @@ struct xfs_message_wakeup_data {
   u_int32_t error;			/* Return value */
   u_int32_t len;
   u_int32_t pad1;
-  char msg[2048] ;    /* XXX */
+  char msg[XFS_MSG_MAX_DATASIZE];
 };
 
 /* XFS_MESSAGE_UPDATEFID */
@@ -471,4 +474,21 @@ struct xfs_message_gc_nodes {
   u_int32_t pad1;
   xfs_handle handle[XFS_GC_NODES_MAX_HANDLE];
 };
+
+#if 0 
+struct xfs_name {
+    u_int16_t name;
+    char name[1];
+};
+#endif
+
+struct xfs_message_bulkgetnode {
+  struct xfs_message_header header;
+  xfs_handle parent_handle;
+  uint32_t flags;
+#define XFS_BGN_LAZY		0x1
+  uint32_t numnodes;
+  struct xfs_handle handles[1];
+};
+
 #endif /* _xmsg_h */
