@@ -33,7 +33,7 @@
 
 #include <xfs/xfs_locl.h>
 
-RCSID("$Id: xfs_syscalls.c,v 1.8 2000/10/02 23:42:33 lha Exp $");
+RCSID("$Id: xfs_syscalls.c,v 1.8.2.1 2002/08/13 15:20:52 lha Exp $");
 
 /*
  * XFS system calls.
@@ -144,7 +144,12 @@ xfs_pioctl_call(char *a_pathP,
     if (error) 
 	return error;
 
-    if (vice_ioctl.in_size > 2048) {
+    if (vice_ioctl.in_size < 0) {
+	printf("remote pioctl: got a negative data size: opcode: %d",
+	       a_opcode);
+	return EINVAL;
+    }
+    if (vice_ioctl.in_size > XFS_MSG_MAX_DATASIZE) {
 	printf("xfs_pioctl_call: got a humongous in packet: opcode: %d",
 	       a_opcode);
 	return EINVAL;
