@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 1999 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1998 - 2000 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -14,12 +14,7 @@
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  * 
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the Kungliga Tekniska
- *      Hgskolan and its contributors.
- * 
- * 4. Neither the name of the Institute nor the names of its contributors
+ * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
@@ -50,7 +45,7 @@
 #include <errno.h>
 #include <dlfcn.h>
 
-RCSID("$Id: getcwd.c,v 1.12 1999/06/15 12:00:43 map Exp $");
+RCSID("$Id: getcwd.c,v 1.14 2000/10/02 23:47:11 lha Exp $");
 
 #ifdef __NR_getcwd
 
@@ -63,11 +58,7 @@ _syscall2(int, sys_getcwd, char *, buf, size_t, size)
 
 #define __NR_sys_lstat __NR_lstat
 
-#if HAVE_STRUCT_NEW_STAT
-typedef struct new_stat kern_stat;
-#else
 typedef struct stat kern_stat;
-#endif
 
 static
 _syscall2(int, sys_lstat, char *, filename, kern_stat *, statbuf)
