@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -31,7 +34,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: xfs_common.h,v 1.26 2000/10/18 01:04:43 lha Exp $ */
+/* $Id: xfs_common.h,v 1.26.2.2 2002/09/07 19:55:32 lha Exp $ */
 
 #ifndef _xfs_common_h
 #define _xfs_common_h
@@ -60,7 +63,8 @@ extern struct file_operations xfs_file_operations,
 			      xfs_link_operations;
 
 struct xfs_dentry_data {
-    int valid;
+    int node_valid;
+    int name_valid;
     struct semaphore sem;
 };
 
