@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -31,7 +34,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: xfs_locl.h,v 1.51 2000/12/10 23:05:26 lha Exp $ */
+/* $Id: xfs_locl.h,v 1.51.2.3 2002/02/01 17:05:14 lha Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -44,10 +47,19 @@
 #include <linux/modversions.h>
 #endif
 #include <linux/version.h>
+
+#if LINUX_VERSION_CODE >= 0x20300
+#define LINUX2_3 1 
+#endif
+
 #include <linux/module.h>
 #include <linux/errno.h>
 #include <linux/fs.h>
+#ifndef LINUX2_3
 #include <linux/malloc.h>
+#else
+#include <linux/slab.h>
+#endif
 #include <linux/time.h>
 #include <linux/sched.h>
 #include <linux/stat.h>
@@ -66,10 +78,6 @@
 # define DEVFS_SUPPORT
 #endif
 
-#if LINUX_VERSION_CODE >= 0x20300
-#define LINUX2_3 1 
-#endif
-
 /*
  * Linux 2.3.39 and above has a new setgroups() system call for
  * 32-bit UIDs, on arm, i386, m68k, sh, and sparc32. The old system call
@@ -143,8 +151,7 @@ typedef __u32  u_int32_t;
 #include <xfs/xfs_node.h>
 #include <xfs/xfs_deb.h>
 
-int
-xfs_replace_root(struct super_block *sb);
+int xfs_fetch_xnode(struct inode *i);
 
 extern struct dentry_operations xfs_dentry_operations;
 
@@ -241,3 +248,22 @@ extern struct address_space_operations xfs_aops;
 #ifndef list_for_each
 #define list_for_each(pos, head) for (pos = (head)->next; pos != (head); pos = pos->next)
 #endif /* list_for_each */
+
+
+#ifndef list_for_each_safe
+#define list_for_each_safe(pos, n, head) \
+	for (pos = (head)->next, n = pos->next; pos != (head); \
+		pos = n, n = pos->next)
+#endif
+
+#ifndef HAVE_INIT_MUTEX
+#define init_MUTEX(m) 	do { *(m) = MUTEX; } while (0)
+#endif
+
+#ifndef HAVE_LIST_DEL_INIT
+static __inline__ void list_del_init(struct list_head *entry)
+{
+	list_del(entry);
+	INIT_LIST_HEAD(entry); 
+}
+#endif
