@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 1996, 1997 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -14,15 +14,13 @@
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  * 
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the Kungliga Tekniska
- *      Hgskolan and its contributors.
- * 
- * 4. Neither the name of the Institute nor the names of its contributors
+ * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ *
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -41,59 +39,50 @@
 #include <xfs/xfs_locl.h>
 #include <xfs/xfs_common.h>
 
-RCSID("$Id: xfs_common.c,v 1.19 1999/01/10 18:28:28 map Exp $");
+RCSID("$Id: xfs_common.c,v 1.27.2.1 2002/02/01 17:04:44 lha Exp $");
 
 #ifdef DEBUG
-static u_int xfs_allocs[10]={0,0,0,0,0,0,0,0,0,0};
-static u_int xfs_frees[10]={0,0,0,0,0,0,0,0,0,0};
+#define XFS_MALLOC_CNT 10
+static u_int xfs_allocs[XFS_MALLOC_CNT]={0,0,0,0,0,0,0,0,0,0};
+static u_int xfs_frees[XFS_MALLOC_CNT]={0,0,0,0,0,0,0,0,0,0};
 #endif
 
 void *
-xfs_alloc(u_int size, int service)
+xfs_alloc(u_int size, unsigned int service)
 {
 #ifdef DEBUG
-    xfs_allocs[service]++;
+    if (service < XFS_MALLOC_CNT)
+	xfs_allocs[service]++;
+    else
+	printk ("xfs_alloc: bad service\n");
 #endif
     return kmalloc (size, GFP_KERNEL); /* What kind? */
 }
 
 void
-xfs_tell_alloc()
+xfs_tell_alloc(void)
 {
 #ifdef DEBUG
     int i;
-    XFSDEB(XDEBMEM, ("xfs_alloc: xfs_allocs - xfs_frees ="));
-    for (i = 0; i < 8; i++)
+    printk ("xfs_alloc: xfs_allocs - xfs_frees =");
+    for (i = 0; i < XFS_MALLOC_CNT; i++)
 	printk(" %d", xfs_allocs[i] - xfs_frees[i]);
-    XFSDEB(XDEBMEM, ("\n"));
+    printk ("\n");
 #endif
 }
 
 void
-xfs_free(void *ptr, int service)
+xfs_free(void *ptr, unsigned int service)
 {
 #ifdef DEBUG
-    xfs_frees[service]++;
+    if (service < XFS_MALLOC_CNT)
+	xfs_frees[service]++;
+    else
+	printk ("xfs_free: bad service\n");
 #endif
     kfree (ptr);
 }
 
-#ifndef LINUX2_1
-int
-init_private_file(struct file *filp, struct inode *inode, int mode)
-{
-    memset(filp, 0, sizeof(struct file));
-    filp->f_mode = mode;
-    filp->f_count = 1;
-    filp->f_op = inode->i_op->default_file_ops;
-    if (filp->f_op->open)
-	return filp->f_op->open(inode, filp);
-    else
-	return 0;
-}
-#endif
-
-#ifdef LINUX2_1
 void
 print_aliases(struct inode *inode)
 {
@@ -109,8 +98,8 @@ print_aliases(struct inode *inode)
 	}
 	dentry = list_entry(alias, struct dentry, d_alias);
 	if (dentry)
-	    XFSDEB(XDEBVFOPS,(" %*s(%p)",
-			      dentry->d_name.len,
+	    XFSDEB(XDEBVFOPS,(" %.*s(%p)",
+			      (int)dentry->d_name.len,
 			      dentry->d_name.name,
 			      dentry));
 	alias = alias->next;
@@ -129,8 +118,8 @@ print_childs(struct dentry *dentry)
 	struct list_head *tmp = subdirs;
 	struct dentry *child = list_entry(tmp, struct dentry, d_child);
 
-	XFSDEB(XDEBVFOPS,(" %*s(%p)",
-			  child->d_name.len,
+	XFSDEB(XDEBVFOPS,(" %.*s(%p)",
+			  (int)child->d_name.len,
 			  child->d_name.name,
 			  child));
 	
@@ -139,4 +128,24 @@ print_childs(struct dentry *dentry)
 
     XFSDEB(XDEBVFOPS,("\n"));
 }
+
+#ifndef HAVE_KERNEL_STRLCPY
+
+size_t
+strlcpy (char *dst, const char *src, size_t dst_sz)
+{
+    size_t n;
+    char *p;
+
+    for (p = dst, n = 0;
+	 n + 1 < dst_sz && *src != '\0';
+	 ++p, ++src, ++n)
+	*p = *src;
+    *p = '\0';
+    if (*src == '\0')
+	return n;
+    else
+	return n + strlen (src);
+}
+
 #endif
