@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 1996, 1997 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 1997, 2000, 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ *
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -36,7 +39,7 @@
 #include <xfs/xfs_locl.h>
 #include <xfs/xfs_deb.h>
 
-RCSID("$Id: xfs_deb.c,v 1.3 2000/10/02 23:47:21 lha Exp $");
+RCSID("$Id: xfs_deb.c,v 1.3.2.1 2002/02/01 17:04:45 lha Exp $");
 
 /* X is on */
 #define X(y) y
