@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -17,6 +17,9 @@
  * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
+ *
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
  * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -36,7 +39,7 @@
 #include <xfs/xfs_locl.h>
 #include <linux/poll.h>
 
-RCSID("$Id: xfs_dev.c,v 1.77.2.2 2001/07/26 02:06:20 assar Exp $");
+RCSID("$Id: xfs_dev.c,v 1.77.2.7 2002/05/18 00:13:31 mattiasa Exp $");
 
 #include <xfs/xfs_message.h>
 #include <xfs/xfs_msg_locl.h>
@@ -118,6 +121,18 @@ xfs_outq(struct xfs_link *p)
     p->next = p->prev = 0;
 }
 
+static void
+free_node(struct xfs_node *xn)
+{
+    if ((xn->flags & XFS_XDELETED) == 0)
+	BUG();
+    if (xn_deletedp(xn))
+	BUG();
+    if (!list_empty(&xn->inactive_list))
+	BUG();
+    xfs_free(xn, XFS_MEM_XNODE);
+}
+
 /*
  * Enqueue the `message' of `size' to the `chan' for later processing.
  */
@@ -168,7 +183,15 @@ xfs_queue_inactive (struct xfs_node *xn)
     XFSDEB(XDEBDEV, ("xfs_queue_inactive\n"));
 
     down(&chan->channel_sem);
-    list_add (&xn->inactive_list, &chan->inactive_list);
+
+    if (chan->status & CHANNEL_OPENED) {
+	if (list_empty(&xn->inactive_list))
+	    list_add (&xn->inactive_list, &chan->inactive_list);
+    } else if (xn->flags & XFS_XDELETED) {
+	INIT_LIST_HEAD(&xn->inactive_list);
+	free_node(xn);
+    }
+	
     up(&chan->channel_sem);
     wake_up(&chan->wait_queue);
 }
@@ -198,23 +221,28 @@ xfs_process_inactive_queue (struct xfs_channel *chan)
 
 	msg.header.opcode = XFS_MSG_INACTIVENODE;
 	msg.handle        = xn->handle;
-	msg.flag          = XFS_NOREFS | XFS_DELETE;
+	if (xn->flags & XFS_XDELETED)
+	    msg.flag          = XFS_NOREFS | XFS_DELETE;
+	else
+	    msg.flag          = XFS_NOREFS;
 	
-	list_del (&xn->inactive_list);
+	list_del_init (&xn->inactive_list);
 
 	up(&chan->channel_sem);
 	ret = enqueue_message (chan, &msg.header, sizeof(msg));
 	down(&chan->channel_sem);
  	if (ret == 0) {
-	    xfs_free(xn, XFS_MEM_XNODE);
+	    if (xn->flags & XFS_XDELETED)
+		free_node(xn);
 	} else {
-	    list_add (&xn->inactive_list, &chan->inactive_list);
+	    if (list_empty(&xn->inactive_list))
+		list_add (&xn->inactive_list, &chan->inactive_list);
 	    XFSDEB(XDEBDEV, ("xfs_process_inactive_queue: "
 			     "failed enqueue-ing msg %d\n", ret));
 	}
     }
     up(&chan->channel_sem);
-    if (i)
+    if (i) 
 	XFSDEB(XDEBDEV, ("xfs_process_inactive_queue: done (%d)\n", i));
 }
 
@@ -239,8 +267,10 @@ xfs_empty_inactive_queue (struct xfs_channel *chan)
 	++i;
 
 	xn = list_entry (lh, struct xfs_node, inactive_list);
-	list_del (&xn->inactive_list);
-	xfs_free(xn, XFS_MEM_XNODE);
+	list_del_init (&xn->inactive_list);
+
+	if (xn->flags & XFS_XDELETED) 
+	    free_node(xn);
     }
     if (i)
 	XFSDEB(XDEBDEV, ("xfs_empty_inactive_queue: done (%d)\n", i));
@@ -287,8 +317,6 @@ xfs_devopen(struct inode *inode, struct file *file)
     chan->status |= CHANNEL_OPENED;
     xfsp->status |= XFS_DEVOPEN;
 
-    INIT_LIST_HEAD(&chan->inactive_list);
-
  out:
     unlock_kernel();
     return ret;
@@ -608,12 +636,12 @@ xfs_message_rpc(int fd, struct xfs_message_header *message, u_int size)
     xfs_appendq(&chan->sleepq, this_process);
     
     this_process->error_or_size = 0;
+    this_process->woken = 0;
 
     up(&chan->channel_sem);
     
     wake_up(&chan->wait_queue);
     
-    this_process->woken = 0;
     while (!sigisactive(current, SIGINT) &&
 	   !sigisactive(current, SIGTERM) &&
 	   !sigisactive(current, SIGKILL) &&
@@ -831,11 +859,8 @@ xfs_init_device(void)
 	init_waitqueue_head(&(xfs_channel[i].wait_queue));
 	xfs_initq(&xfs_channel[i].messageq);
 	xfs_initq(&xfs_channel[i].sleepq);
-#ifdef HAVE_INIT_MUTEX	
-	init_MUTEX(&(xfs_channel[i].channel_sem));
-#else
-	xfs_channel[i].channel_sem = MUTEX;
-#endif
+	init_MUTEX(&xfs_channel[i].channel_sem);
+	INIT_LIST_HEAD(&xfs_channel[i].inactive_list);
     }
     return 0;
 }
