@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995-2000 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995-2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -41,13 +44,18 @@
 #include <linux/file.h>
 #include <linux/mm.h>
 
-RCSID("$Id: xfs_inodeops.c,v 1.149.2.1 2001/01/28 16:13:38 lha Exp $");
+RCSID("$Id: xfs_inodeops.c,v 1.149.2.8 2002/09/08 09:11:23 mattiasa Exp $");
 
 static struct dentry *
 xfs_lookup (struct inode *inode, struct dentry *dentry);
 
+#ifndef LINUX2_3
 static int
 xfs_fsync(struct file *file, struct dentry *dentry);
+#else /* LINUX2_3 */
+static int
+xfs_fsync(struct file *file, struct dentry *dentry, int datasync);
+#endif /* LINUX2_3 */
 
 static int
 do_fsync(struct xfs *xfsp, struct xfs_node *xn, u_int flag);
@@ -83,6 +91,8 @@ static int xfs_symlink(struct inode *dir, struct dentry *dentry,
 static int xfs_link(struct dentry *old_dentry,
 		    struct inode *dir, struct dentry *dentry);
 
+static int xfs_revalidate_inode(struct dentry *dentry);
+
 static int
 xfs_release_file (struct inode *inode, struct file *file);
 
@@ -95,7 +105,12 @@ static int xfs_mmap (struct file *file,
 static int
 xfs_readlink(struct dentry *dentry, char *buffer, int buflen);
 
-static int
+static
+#if HAVE_D_DELETE_VOID
+void
+#else
+int
+#endif
 xfs_d_delete(struct dentry *dentry);
 
 static int
@@ -104,9 +119,6 @@ xfs_d_revalidate(struct dentry *dentry, int flags);
 static void
 xfs_d_release(struct dentry *dentry);
 
-static struct dentry *
-xfs_dead_lookup (struct inode *dir, struct dentry *dentry);
-
 static ssize_t
 xfs_write_file(struct file *file, const char *buf, size_t count, loff_t *ppos);
 
@@ -141,84 +153,18 @@ xfs_follow_link (struct dentry *dentry, struct nameidata *nd);
 
 #endif /* LINUX2_3 */
 
-#ifdef LINUX2_3
-
 /*
- * Address Space operations
- *
- * These are just placeholders to warn if we do the wrong thing
- * and use them.
- *
- * We pull the handle big time and oops, this shouldn't happen.
+ * Return 1 if the `vma' can cause a write to the filesystem, 0 if not.
  */
 
 static int
-xfs_as_writepage(struct file *file, struct page *page)
+xfs_mightwrite_p (struct vm_area_struct *vma)
 {
-    printk ("XFS PANIC: xfs_as_writepage\n");
-    *(int *) NULL = 10;
-    return -EIO;
+    if (vma->vm_flags & VM_MAYWRITE && vma->vm_flags & VM_SHARED)
+	return 1;
+    return 0;
 }
 
-static int
-xfs_as_readpage(struct file *file, struct page *page)
-{
-    printk ("XFS PANIC: xfs_as_readpage\n");
-    *(int *) NULL = 10;
-    return -EIO;
-}
-
-static int
-xfs_as_syncpage(struct page *page)
-{
-    printk ("XFS PANIC: xfs_as_syncpage\n");
-    *(int *) NULL = 10;
-    return -EIO;
-}
-
-static int
-xfs_as_prepare_write(struct file * file, struct page *page,
-		     unsigned foo, unsigned bar)
-{
-    printk ("XFS PANIC: xfs_as_prepare_write\n");
-    *(int *) NULL = 10;
-    return -EIO;
-}
-
-static int
-xfs_as_commit_write(struct file *file, struct page *page,
-		    unsigned foo, unsigned bar)
-{
-    printk ("XFS PANIC: xfs_as_commit_write\n");
-    *(int *) NULL = 10;
-    return -EIO;
-}
-
-static int
-xfs_as_bmap(struct address_space *foo, long bar)
-{
-    printk ("XFS PANIC: xfs_as_bmap\n");
-    *(int *) NULL = 10;
-    return -EIO;
-}
-
-struct address_space_operations xfs_aops = {
-    writepage: xfs_as_writepage,
-    readpage: xfs_as_readpage,
-    sync_page: xfs_as_syncpage,
-    prepare_write: xfs_as_prepare_write,
-    commit_write: xfs_as_commit_write,
-    bmap: xfs_as_bmap,
-};
-
-/*
- * We need to fetch the close operation (and store the file
- * to the fileserver).
- */
-
-struct vm_operations_struct xfs_file_shared_mmap;
-struct vm_operations_struct xfs_file_private_mmap;
-
 /*
  * When we close the mmap:ed memory, flush the data to the fileserver
  */
@@ -232,23 +178,41 @@ xfs_vma_close (struct vm_area_struct *vma)
     struct xfs *xfsp = XFS_FROM_VNODE(inode);
     struct xfs_node *xn = VNODE_TO_XNODE(inode);
 
-    XFSDEB(XDEBVNOPS, ("xfs_vma_close\n"));
+    XFSDEB(XDEBVNOPS, ("xfs_vma_close: count: %d\n", xfs_icount(inode)));
 
     /*
      * I really want to hook the xfs_as_writepage, but then everything
      * will be cache:ed in the wrong struct address_space
      */
 
-    if (file->f_mode & FMODE_WRITE && vma->vm_flags & VM_MAYWRITE) {
+    if (file->f_mode & FMODE_WRITE && xfs_mightwrite_p(vma)) {
 	error = do_fsync(xfsp, xn, XFS_WRITE);
 	if (error) {
 	    XFSDEB(XDEBVNOPS, ("xfs_vma_close: do_fsync returned %d\n",
 			       error));
 	}
     }
-    iput(inode);
 }
 
+/*
+ * In linux2.2 there are un-exported functions in the vm that needs to
+ * called (since we are lazy bums and don't want to rewrite/copy them
+ * them). This is not needed for linux2.4 and world is somewhat
+ * kinder to us.
+ */
+
+#ifndef LINUX2_3
+
+struct vm_operations_struct xfs_file_shared_mmap;
+struct vm_operations_struct xfs_file_private_mmap;
+
+#else
+
+static struct vm_operations_struct xfs_file_vm_ops = {
+    nopage:	filemap_nopage,
+    close:	xfs_vma_close,
+};
+
 #endif /* LINUX2_3 */
 
 
@@ -308,12 +272,11 @@ struct inode_operations xfs_file_inode_operations = {
     default_file_ops:	&xfs_file_operations,
     readpage:		xfs_readpage,
     permission:		xfs_permission,
-    
+    revalidate:		xfs_revalidate_inode,
 };
 
 struct inode_operations xfs_dead_inode_operations = {
     default_file_ops:	&xfs_dead_operations,
-    lookup:		xfs_dead_lookup,
 };
 
 struct inode_operations xfs_dir_inode_operations = {
@@ -327,51 +290,55 @@ struct inode_operations xfs_dir_inode_operations = {
     rmdir:		xfs_rmdir,
     rename:		xfs_rename,
     permission:		xfs_permission,
+    revalidate:		xfs_revalidate_inode,
 };    
 
 struct inode_operations xfs_link_inode_operations = {
     default_file_ops:	&xfs_link_operations,
     readlink:		xfs_readlink,
     follow_link:	xfs_follow_link,
+    revalidate:		xfs_revalidate_inode,
 };
 
 #else /* LINUX2_3 */
 
 struct inode_operations xfs_file_inode_operations = {
-    permission: xfs_permission,
-    setattr: xfs_setattr,
-    getattr: xfs_getattr,
+    permission:		xfs_permission,
+    setattr:		xfs_setattr,
+    getattr:		xfs_getattr,
+    revalidate:		xfs_revalidate_inode,
 };
 
 struct inode_operations xfs_dir_inode_operations = {
-    create: xfs_create,
-    lookup: xfs_lookup,
-    link: xfs_link,
-    unlink: xfs_unlink,
-    symlink: xfs_symlink,
-    mkdir: xfs_mkdir,
-    rmdir: xfs_rmdir,
-    rename: xfs_rename,
-    permission: xfs_permission,
-    setattr: xfs_setattr,
-    getattr: xfs_getattr,
+    create:		xfs_create,
+    lookup:		xfs_lookup,
+    link:		xfs_link,
+    unlink:		xfs_unlink,
+    symlink:		xfs_symlink,
+    mkdir:		xfs_mkdir,
+    rmdir:		xfs_rmdir,
+    rename:		xfs_rename,
+    permission:		xfs_permission,
+    setattr:		xfs_setattr,
+    getattr:		xfs_getattr,
+    revalidate:		xfs_revalidate_inode,
 };
 
 struct inode_operations xfs_dead_inode_operations = {
-    lookup: xfs_dead_lookup
 };
 
 struct inode_operations xfs_link_inode_operations = {
-    readlink: xfs_readlink,
-    follow_link: xfs_follow_link,
+    readlink:		xfs_readlink,
+    follow_link:	xfs_follow_link,
+    revalidate: 	xfs_revalidate_inode,
 };
 
 #endif /* LINUX2_3 */
 
 struct dentry_operations xfs_dentry_operations = {
-    d_revalidate: xfs_d_revalidate,
-    d_delete	: xfs_d_delete,
-    d_release	: xfs_d_release,
+    d_revalidate:	xfs_d_revalidate,
+    d_delete	:	xfs_d_delete,
+    d_release	:	xfs_d_release,
 };
 
 /*
@@ -414,7 +381,8 @@ xfs_d_init (struct dentry *dentry)
         return -ENOMEM;
     memset(dentry_data, 0, sizeof(*dentry_data));
     dentry->d_op = &xfs_dentry_operations;
-    dentry_data->valid = 0;
+    dentry_data->node_valid = 0;
+    dentry_data->name_valid = 0;
     sema_init(&dentry_data->sem, 1);
     xfs_print_lock("xfs_d_init",&dentry_data->sem);
     dentry->d_fsdata = dentry_data;
@@ -462,8 +430,14 @@ xfs_lookup (struct inode *dir, struct dentry *dentry)
     xfsp = XFS_FROM_VNODE(dir);
     d = VNODE_TO_XNODE(dir);
     if (d == NULL || xfsp == NULL) {
-        XFSDEB(XDEBVNOPS, ("ENODEV\n"));
-	return ERR_PTR(-ENODEV);
+        XFSDEB(XDEBVNOPS, ("xfs_lookup: fetch xnode\n"));
+	error = xfs_fetch_xnode(dir);
+	if (error)
+	    return ERR_PTR(error);
+	xfsp = XFS_FROM_VNODE(dir);
+	d = VNODE_TO_XNODE(dir);
+	if (d == NULL || xfsp == NULL)
+	    return ERR_PTR(-ENODEV);
     }
 
     do {
@@ -478,7 +452,7 @@ xfs_lookup (struct inode *dir, struct dentry *dentry)
 
 	new_dentry = d_lookup(dentry->d_parent, &dentry->d_name);
 
-	if (new_dentry && DENTRY_TO_XDENTRY(new_dentry)->valid)
+	if (new_dentry && DENTRY_TO_XDENTRY(new_dentry)->node_valid)
 	    break;
 
 	if (new_dentry)
@@ -504,7 +478,8 @@ xfs_lookup (struct inode *dir, struct dentry *dentry)
 
 	d_add(new_dentry, NULL);
 	
-	DENTRY_TO_XDENTRY(new_dentry)->valid = 1;
+	DENTRY_TO_XDENTRY(new_dentry)->node_valid = 1;
+	DENTRY_TO_XDENTRY(new_dentry)->name_valid = 1;
         return NULL;
     }
     if (error) {
@@ -527,6 +502,9 @@ xfs_open_valid(struct inode *vp, u_int tok)
 
   XFSDEB(XDEBVFOPS, ("xfs_open_valid: tokens 0x%x\n", xn->tokens));
   
+  if (xn == NULL)
+      return -ENODEV;
+  
   do {
     if (!XFS_TOKEN_GOT(xn, tok))
       {
@@ -578,6 +556,9 @@ do_fsync(struct xfs *xfsp, struct xfs_node *xn, u_int flag)
     int error;
     struct xfs_message_putdata msg;
 
+    if (xn == NULL)
+	return -ENODEV;
+
     msg.header.opcode = XFS_MSG_PUTDATA;
     msg.cred.uid = current->uid;
     msg.cred.pag = xfs_get_pag();
@@ -602,22 +583,27 @@ do_fsync(struct xfs *xfsp, struct xfs_node *xn, u_int flag)
  *
  */
 
+#ifndef LINUX2_3
 static int
 xfs_fsync(struct file *file, struct dentry *dentry)
+#else /* LINUX2_3 */
+static int
+xfs_fsync(struct file *file, struct dentry *dentry, int datasync)
+#endif /* LINUX2_3 */
 {
     struct inode *inode = DENTRY_TO_INODE(dentry);
     struct xfs *xfsp = XFS_FROM_VNODE(inode);
     struct xfs_node *xn = VNODE_TO_XNODE(inode);
     int error = 0;
 
+    if (xn == NULL)
+	return -ENODEV;
+
     XFSDEB(XDEBVNOPS, ("xfs_fsync: 0x%p\n", inode));
     XFSDEB(XDEBVNOPS, ("xfs_fsync: name: %.*s aliases:",
 		       (int)dentry->d_name.len, dentry->d_name.name));
     print_aliases(inode);
 
-    if (xn == NULL)
-	return 0;
-
     if (xn->flags & XFS_DATA_DIRTY)
 	error = do_fsync(xfsp, xn, XFS_WRITE | XFS_FSYNC);
     return error;
@@ -628,14 +614,12 @@ xfs_fsync(struct file *file, struct dentry *dentry)
  */
 
 static int
-xfs_attr_valid(struct inode * vp, u_int tok)
+xfs_attr_valid(struct inode * vp, u_int tok, xfs_pag_t pag)
 {
     struct xfs *xfsp = XFS_FROM_VNODE(vp);
     struct xfs_node *xn = VNODE_TO_XNODE(vp);
     int error = 0;
 
-    xfs_pag_t pag = xfs_get_pag();
-
     do {
         if (!XFS_TOKEN_GOT(xn, tok)) {
             struct xfs_message_getattr msg;
@@ -668,6 +652,9 @@ xfs_rights_valid(struct inode * vp, xfs_pag_t pag)
     int error = 0;
     XFSDEB(XDEBVNOPS, ("pag: %d\n", pag));
 
+    if (xn == NULL)
+	return -ENODEV;
+
     do {
         if (!xfs_has_pag(xn, pag))
         {
@@ -725,12 +712,14 @@ xfs_permission(struct inode *inode, int mode)
     print_aliases(inode);
 
     if (VNODE_TO_XNODE(inode) == NULL) {
-       printk(KERN_EMERG "XFS Panic: xnode == NULL in xfs_permission\n");
-       printk(KERN_EMERG "   inode = %p i_ino: 0x%lx\n", inode, inode->i_ino);
-       return -EACCES;
+	error = xfs_fetch_xnode(inode);
+	if (error)
+	    return error;
+	if (VNODE_TO_XNODE(inode) == NULL)
+	    return -ENODEV;
     }
 
-    error = xfs_attr_valid(inode, XFS_ATTR_R);
+    error = xfs_attr_valid(inode, XFS_ATTR_R, pag);
     if (error == 0) {
 	struct xfs_node *xn = VNODE_TO_XNODE(inode);
 	int i;
@@ -769,10 +758,14 @@ xfs_data_valid(struct inode *vp, u_int tok)
   struct xfs_node *xn = VNODE_TO_XNODE(vp);
   int error = 0;
   
+  if (xn == NULL)
+      return -ENODEV;
+
   do {
     if (!XFS_TOKEN_GOT(xn, tok))
       {
 	struct xfs_message_getdata msg;
+
 	msg.header.opcode = XFS_MSG_GETDATA;
 	msg.cred.uid = current->uid;
 	msg.cred.pag = xfs_get_pag();
@@ -792,6 +785,32 @@ xfs_data_valid(struct inode *vp, u_int tok)
   return error;
 }
 
+/*
+ *
+ */
+
+static int
+xfs_revalidate_inode(struct dentry *dentry)
+{
+    struct inode *inode = DENTRY_TO_INODE(dentry);
+    xfs_pag_t pag = xfs_get_pag();
+    int error;
+
+    XFSDEB(XDEBVNOPS, ("xfs_revalidate_node: dentry: %p inode: %p\n",
+		       dentry, inode));
+
+    XFSDEB(XDEBVNOPS, ("xfs_revalidate_node: xnode: %p xfs: %p\n",
+		       VNODE_TO_XNODE(inode), XFS_FROM_VNODE(inode)));
+
+    if (VNODE_TO_XNODE(inode) == NULL || XFS_FROM_VNODE(inode) == NULL) {
+	error = xfs_fetch_xnode(inode);
+	if (error)
+	    return error;
+    }
+
+    return xfs_attr_valid(inode, XFS_ATTR_R, pag);
+}
+
 /*
  * Called when the cached node has been changed, to update the relevant
  * part of the `overlaying' node.
@@ -815,44 +834,60 @@ update_from_cache_node (struct inode *inode)
 static int xfs_mmap (struct file *file,
 		     struct vm_area_struct *vma)
 {
-    int error = 0;
+    int flags, error = 0;
     struct inode *inode = file->f_dentry->d_inode;
+#ifdef LINUX2_3
+    struct address_space *mapping = inode->i_mapping;
+#endif
     
     XFSDEB(XDEBVNOPS, ("xfs_mmap inode: %p\n", inode));
     xfs_print_path(file->f_dentry);
     XFSDEB(XDEBVNOPS, ("xfs_mmap aliases:"));
     print_aliases(inode);
     
-    error = xfs_data_valid(inode, XFS_DATA_R);
-    if (error == 0) {
-	error = generic_file_mmap(file, vma);
-	if (error)
-	    return error;
+    if (xfs_mightwrite_p(vma))
+	flags = XFS_DATA_W;
+    else
+	flags = XFS_DATA_R;
 
-#ifdef LINUX2_3
-	/*
-	 * The first time, if we are not init-ed copy the
-	 * struct since its static in mm/filemap.c
-	 *
-	 * We need to know when the file is munmap, so
-	 * hook the close.
-	 */
-	if ((vma->vm_flags & VM_SHARED) && (vma->vm_flags & VM_MAYWRITE)) {
-	    if (xfs_file_shared_mmap.close == NULL) {
-		xfs_file_shared_mmap = *vma->vm_ops;
-		xfs_file_shared_mmap.close = xfs_vma_close;
-	    }
-	    vma->vm_ops = &xfs_file_shared_mmap;
-	} else {
-	    if (xfs_file_private_mmap.close == NULL) {
-		xfs_file_private_mmap = *vma->vm_ops;
-		xfs_file_private_mmap.close = xfs_vma_close;
-	    } 
-	    vma->vm_ops = &xfs_file_private_mmap;
-	}	    
-	xfs_iref(inode);
-#endif
+    error = xfs_data_valid(inode, flags);
+    if (error != 0)
+	goto done;
+
+    XFSDEB(XDEBVNOPS, ("xfs_mmap: data valid\n"));
+
+#ifndef LINUX2_3
+    error = generic_file_mmap(file, vma);
+    if (error != 0)
+	goto done;
+
+    if ((vma->vm_flags & VM_SHARED) && (vma->vm_flags & VM_MAYWRITE)) {
+	if (xfs_file_shared_mmap.close == NULL) {
+	    xfs_file_shared_mmap = *vma->vm_ops;
+	    xfs_file_shared_mmap.close = xfs_vma_close;
+	}
+	vma->vm_ops = &xfs_file_shared_mmap;
+    } else {
+	if (xfs_file_private_mmap.close == NULL) {
+	    xfs_file_private_mmap = *vma->vm_ops;
+	    xfs_file_private_mmap.close = xfs_vma_close;
+	}
+	vma->vm_ops = &xfs_file_private_mmap;
     }
+#else
+    /* ~ inlined generic_file_mmap */
+    if (xfs_mightwrite_p(vma)) {
+	if (!mapping->a_ops->writepage)
+	    return -EINVAL;
+    }
+    if (!mapping->a_ops->readpage)
+	return -ENOEXEC;
+
+    vma->vm_ops = &xfs_file_vm_ops;
+#endif
+ done:
+    XFSDEB(XDEBVNOPS, ("xfs_mmap: done %d\n", error));
+
     return error;
 }
 
@@ -1134,7 +1169,7 @@ xfs_create (struct inode * dir, struct dentry *dentry, int mode)
 	error = ((struct xfs_message_wakeup *) & msg)->error;
 
     /* XXX should this really be here with new style dcache insert */
-    if (!DENTRY_TO_XDENTRY(dentry)->valid) {
+    if (!DENTRY_TO_XDENTRY(dentry)->node_valid) {
 	printk(KERN_EMERG "XFS Panic: xfs_create: dentry not valid\n");
     }
 
@@ -1263,7 +1298,7 @@ xfs_mkdir(struct inode * dir, struct dentry *dentry, int mode)
 	    error = ((struct xfs_message_wakeup *) & msg)->error;
 
 	/* XXX should this really be here */
-	if (!DENTRY_TO_XDENTRY(dentry)->valid) {
+	if (!DENTRY_TO_XDENTRY(dentry)->node_valid) {
 	    printk(KERN_EMERG "XFS Panic: xfs_mkdir: dentry not valid\n");
 	}
     }
@@ -1375,7 +1410,7 @@ static int xfs_symlink(struct inode *dir, struct dentry *dentry,
 	if (error == 0)
 	    error = ((struct xfs_message_wakeup *) & msg)->error;
 	/* XXX should this really be here */
-	if (!DENTRY_TO_XDENTRY(dentry)->valid) {
+	if (!DENTRY_TO_XDENTRY(dentry)->node_valid) {
 	    printk(KERN_EMERG "XFS Panic: xfs_symlink: dentry not valid\n");
 	}
     }
@@ -1669,11 +1704,16 @@ static int
 xfs_getattr (struct dentry *dentry, struct iattr *attr)
 {
     struct inode *inode = DENTRY_TO_INODE(dentry);
+    struct xfs_node *xn = VNODE_TO_XNODE(inode);
+    xfs_pag_t pag = xfs_get_pag();
     int error;
 
     XFSDEB(XDEBVNOPS, ("xfs_getattr\n"));
 
-    error = xfs_attr_valid(inode, XFS_ATTR_R);
+    if (xn == NULL)
+	return -ENODEV;
+
+    error = xfs_attr_valid(inode, XFS_ATTR_R, pag);
     if (error == 0) {
 	attr->ia_valid = ATTR_MODE | ATTR_UID | ATTR_GID
 	    | ATTR_SIZE | ATTR_ATIME | ATTR_MTIME
@@ -1772,7 +1812,7 @@ xfs_release_file (struct inode *inode, struct file *file)
 	&& (xn->flags & XFS_DATA_DIRTY
 	    || (DATA_FROM_VNODE(inode) != NULL
 		&& DATA_FROM_VNODE(inode)->d_inode != NULL
-		&& DATA_FROM_VNODE(inode)->d_inode->i_state & I_DIRTY)))
+		&& DATA_FROM_VNODE(inode)->d_inode->i_state & (I_DIRTY_DATASYNC | I_DIRTY_PAGES))))
 	error = do_fsync(xfsp, xn, XFS_WRITE);
     
 #ifndef LINUX2_3
@@ -1833,51 +1873,40 @@ xfs_d_revalidate(struct dentry *dentry, int flags)
 		       (int)dentry->d_name.len,
 		       dentry->d_name.name,
 		       inode));
-    xfs_print_lock("xfs_d_revalidate before down",
-		   &DENTRY_TO_XDENTRY(dentry)->sem);
-    down(&DENTRY_TO_XDENTRY(dentry)->sem);
-    xfs_print_lock("xfs_d_revalidate after down",
-		   &DENTRY_TO_XDENTRY(dentry)->sem);
-    xfs_print_lock("xfs_d_revalidate before up",
-		   &DENTRY_TO_XDENTRY(dentry)->sem);
-    up(&DENTRY_TO_XDENTRY(dentry)->sem);
-    xfs_print_lock("xfs_d_revalidate after up",
-		   &DENTRY_TO_XDENTRY(dentry)->sem);
-    if (!DENTRY_TO_XDENTRY(dentry)->valid) {
-#ifndef LINUX2_3
-	if (dentry->d_count == 1) /* We are the only one */
+
+    if (DENTRY_TO_XDENTRY(dentry)->node_valid == 0) {
+	if (xfs_dcount(dentry) == 1) /* We are the only one */
 	    d_drop(dentry);
-#else
-	if (atomic_read(&dentry->d_count) == 1) /* We are the only one */
-	    d_drop(dentry);
-#endif
 	return 0;
     }
 
+    if (DENTRY_TO_XDENTRY(dentry)->name_valid)
+        return 1;
+
     if (inode) {
+        int error;
 	struct xfs_node *xnode = VNODE_TO_XNODE(inode);
 
+	if (xnode == NULL)
+	    return 0;
+
 	print_aliases(inode);
 	if (IS_ROOT(dentry))
 	    return 1;
-	if (xnode) {
-	    if (XFS_TOKEN_GOT(xnode, XFS_ATTR_VALID)) {
-		XFSDEB(XDEBVNOPS, ("valid\n"));
-		return 1;
-	    } else {
+	error = xfs_attr_valid(inode, XFS_ATTR_R, xfs_get_pag());
+	if (error) {
 		XFSDEB(XDEBVNOPS, ("invalid\n"));
 		return 0;
-	    }
 	} else {
-	    printk(KERN_EMERG "XFS Panic: xfs_d_revalidate: "
-		   "inode does not have xnode\n");
-	    return 0;
+		XFSDEB(XDEBVNOPS, ("valid\n"));
+		return 1;
 	}
     } else {
 	/*
 	 * Negative entries are always valid,
 	 * they are cleared in xfs_message_invalidnode
 	 */
+	XFSDEB(XDEBVNOPS, ("xfs_d_revalidate: negative entry\n"));
 	return 1;
     }
     printk(KERN_EMERG "XFS Panic: a case in xfs_d_revalidate has not "
@@ -1885,52 +1914,44 @@ xfs_d_revalidate(struct dentry *dentry, int flags)
     return 0;
 }
 
-/*
- *
- */
-
-static int
+static
+#if HAVE_D_DELETE_VOID
+#define d_delete_return(x) return
+void
+#else
+#define d_delete_return(x) return (x)
+int
+#endif
 xfs_d_delete(struct dentry *dentry)
 {
+    struct inode *inode;
+    struct xfs_node *xn;
+
     XFSDEB(XDEBVNOPS, ("xfs_d_delete: dentry %p(%.*s): "
 		       "all references dropped\n",
 		       dentry,
 		       (int)dentry->d_name.len,
 		       dentry->d_name.name));
-    return 0;
-}
 
-/*
- * when a `dead' operation is attempted on `inode', try replacing it
- * with the real file system.
- * returning 0 if this was succesful.
- */
+    inode = dentry->d_inode;
+    if (inode) {
+	xn = VNODE_TO_XNODE(inode);
 
-static int
-try_replacing (struct inode *inode)
-{
-    struct xfs *xfsp = XFS_FROM_VNODE(inode);
-
-    if (inode->i_op == &xfs_dead_inode_operations
-	&& !(xfsp->status & XFS_ROOTINSTALLED)
-	&& xfs_replace_root (XFS_TO_VFS(xfsp)) == 0)
-	return 0;
-    else
-	return 1;
-}
-
-/*
- *
- */
-
-static struct dentry *
-xfs_dead_lookup (struct inode *dir, struct dentry *dentry)
-{
-    XFSDEB(XDEBVNOPS, ("xfs_dead_lookup: name: %.*s\n", 
-		       (int)dentry->d_name.len, dentry->d_name.name));
-
-    if (try_replacing (dir) == 0)
-	return dir->i_op->lookup(dir, dentry);
-    else
-	return ERR_PTR(-ENOTDIR);
+	if (xn
+	    && (xn->flags & XFS_STALE) != 0
+	    && xfs_icount(inode) == 1)
+	{
+#ifdef HAVE_D_DELETE_VOID
+	    
+	    xfs_force_invalid_xnode (xn);
+	    xfs_queue_inactive(xn);
+	    
+	    xn->flags &= ~XFS_STALE;
+#endif
+	    XFSDEB(XDEBVNOPS, ("xfs_d_delete: stale\n"));
+	    /* this will cause a ->d_delete */
+	    d_delete_return(1);
+	}
+    }
+    d_delete_return(0);
 }
