@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995 - 2001 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -40,7 +43,7 @@
 #include <xfs/xfs_fs.h>
 #include <xfs/xfs_dev.h>
 
-RCSID("$Id: xfs_message.c,v 1.94.2.2 2001/03/04 05:44:45 lha Exp $");
+RCSID("$Id: xfs_message.c,v 1.94.2.5 2002/09/07 19:55:25 lha Exp $");
 
 static void
 clear_all_children (struct inode *inode, int parent);
@@ -50,6 +53,7 @@ xfs_message_installroot(int fd,
 			struct xfs_message_installroot *message,
 			u_int size)
 {
+    struct xfs *xfsp = &xfs[fd];
     int error = 0;
     
     XFSDEB(XDEBMSG, ("xfs_message_installroot\n"));
@@ -58,7 +62,9 @@ xfs_message_installroot(int fd,
 	printk(KERN_EMERG "XFS Panic: xfs_message_installroot again\n");
 	error = -EBUSY;
     } else {
-	xfs[fd].root = new_xfs_node(&xfs[fd], &message->node); /* VN_HOLD's */
+	/* VN_HOLD's */
+	xfsp->root = new_xfs_node(xfsp, &message->node,
+				  XFS_TO_VFS(xfsp)->s_root->d_inode);
     }
 
     return error;
@@ -86,7 +92,7 @@ xfs_message_installnode(int fd,
 	print_aliases(inode);
 
 	XFSDEB(XDEBMSG, ("xfs_message_installnode: fetching new node\n"));
-	n = new_xfs_node(&xfs[fd], &message->node); /* VN_HOLD's */
+	n = new_xfs_node(&xfs[fd], &message->node, NULL); /* VN_HOLD's */
 	XFSDEB(XDEBMSG, ("xfs_message_installnode: inode: %p tokens: 0x%x aliases: ",
 			 XNODE_TO_VNODE(n), n->tokens));
 	print_aliases(XNODE_TO_VNODE(n));
@@ -126,25 +132,27 @@ xfs_message_installnode(int fd,
 		if (dentry->d_inode == NULL) {
 		    xfs_iref(XNODE_TO_VNODE(n));
 		    d_instantiate(dentry, XNODE_TO_VNODE(n));
-		    DENTRY_TO_XDENTRY(dentry)->valid = 1;
+		    DENTRY_TO_XDENTRY(dentry)->node_valid = 1;
+		    DENTRY_TO_XDENTRY(dentry)->name_valid = 1;
 		} else if (dentry->d_inode != XNODE_TO_VNODE(n)) {
 		    printk(KERN_EMERG
 			   "XFS SoftAssert: existing inode "
-			   "(%x, fid %d.%d.%d.%d) != "
-			   "installing %s(%x, fid %d.%d.%d.%d)\n",
-			   (unsigned int)dentry->d_inode,
+			   "(%p, fid %d.%d.%d.%d) != "
+			   "installing %s(%p, fid %d.%d.%d.%d)\n",
+			   dentry->d_inode,
 			   VNODE_TO_XNODE(dentry->d_inode)->handle.a,
 			   VNODE_TO_XNODE(dentry->d_inode)->handle.b,
 			   VNODE_TO_XNODE(dentry->d_inode)->handle.c,
 			   VNODE_TO_XNODE(dentry->d_inode)->handle.d,
 			   message->name,
-			   (unsigned int)XNODE_TO_VNODE(n),
+			   XNODE_TO_VNODE(n),
 			   n->handle.a,
 			   n->handle.b,
 			   n->handle.c,
 			   n->handle.d);
 		} else {
-		    DENTRY_TO_XDENTRY(dentry)->valid = 1;
+		    DENTRY_TO_XDENTRY(dentry)->node_valid = 1;
+		    DENTRY_TO_XDENTRY(dentry)->name_valid = 1;
 		}
 	    } else {
 		/* unprovoked installnode, ie bulkstatus) */
@@ -154,7 +162,8 @@ xfs_message_installnode(int fd,
 				 dentry));
 		error = xfs_d_init(dentry);
 		if (error == 0) {
-		    DENTRY_TO_XDENTRY(dentry)->valid = 1;
+		    DENTRY_TO_XDENTRY(dentry)->node_valid = 1;
+		    DENTRY_TO_XDENTRY(dentry)->name_valid = 1;
 		    xfs_iref(XNODE_TO_VNODE(n));
 		    d_add(dentry, XNODE_TO_VNODE(n));
 		}
@@ -274,7 +283,7 @@ xfs_message_installdata(int fd,
 	if (message->flag & XFS_ID_HANDLE_VALID) {
 	    dentry = xfs_fh_to_dentry(&message->cache_handle);
 	} else {
-	    dentry = ERR_PTR(EINVAL);
+	    dentry = ERR_PTR(-EINVAL);
 	}
 	
 	XFSDEB(XDEBMSG, ("xfs_message_installdata dentry: %p\n",
@@ -294,8 +303,11 @@ xfs_message_installdata(int fd,
 
 		if (path_init (message->cache_name, LOOKUP_POSITIVE, &nd))
 		    error = path_walk (message->cache_name, &nd);
-		if (error == 0)
+		if (error == 0) {
 		    dentry = nd.dentry;
+		    nd.dentry = NULL;
+		    path_release(&nd);
+		}
 	    }
 #endif
 	    if (error) {
@@ -354,7 +366,7 @@ clear_all_children (struct inode *inode, int parent)
 	}
 	xd = DENTRY_TO_XDENTRY(dentry);
 	if (parent)
-	    xd->valid = 0;
+	    xd->name_valid = 0;
 	XFSDEB(XDEBMSG, ("clear_all_children parent: %.*s\n",
 			 (int)dentry->d_name.len, dentry->d_name.name));
 #if 0
@@ -377,7 +389,7 @@ clear_all_children (struct inode *inode, int parent)
 				 "invalidating %p aliases:\n",
 				 child->d_inode));
 		print_aliases(child->d_inode);
-		DENTRY_TO_XDENTRY(child)->valid = 0;
+		DENTRY_TO_XDENTRY(child)->name_valid = 0;
 	    }
 #ifndef LINUX2_3
 	    XFSDEB(XDEBMSG, ("clean_all_children: "
@@ -414,7 +426,10 @@ xfs_invalid_xnode(struct xfs_node *xnode)
 		      num_users));
     
     if (num_users == 0 || S_ISDIR(inode->i_mode)) {
+
 	xfs_force_invalid_xnode(xnode);
+	xfs_queue_inactive(xnode);
+
     } else {
 	xnode->flags |= XFS_STALE;
     }
@@ -539,27 +554,17 @@ xfs_message_gc_nodes(int fd,
 		     struct xfs_message_gc_nodes *message,
 		     u_int size)
 {
+    struct xfs_node *t;
+    int i;
+
     XFSDEB(XDEBMSG, ("xfs_message_gc\n"));
-
-    if (message->len == 0) {
-	struct xfs_node *xnode, *next;
-
-	for (xnode = xfs[fd].nodes; xnode; xnode = next) {
-	    next = xnode->next;
-	    gc_vnode(XNODE_TO_VNODE(xnode));
-	}
+    
+    for (i = 0; i < message->len; i++) {
+	t = xfs_node_find (&xfs[fd], &message->handle[i]);
+	if (t == NULL)
+	    continue;
 	
-    } else {
-	struct xfs_node *t;
-	int i;
-
-	for (i = 0; i < message->len; i++) {
-	    t = xfs_node_find (&xfs[fd], &message->handle[i]);
-	    if (t == NULL)
-		continue;
-
-	    gc_vnode(XNODE_TO_VNODE(t));
-	}
+	gc_vnode(XNODE_TO_VNODE(t));
     }
 
     return 0;
