@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -38,7 +41,123 @@
 #include <xfs/xfs_fs.h>
 #include <xfs/xfs_deb.h>
 
-RCSID("$Id: xfs_node.c,v 1.51.2.3 2001/09/06 23:40:45 ahltorp Exp $");
+RCSID("$Id: xfs_node.c,v 1.51.2.7 2002/05/18 00:14:25 mattiasa Exp $");
+
+#define xn_list_entry(ptr, type, member) \
+        ((type *)((char *)(ptr)-(unsigned long)(&((type *)0)->member)))
+
+#define xn_hash(node) \
+  (((node)->a+(node)->b+(node)->c+(node)->d) % XN_HASHSIZE)
+
+void
+xn_purge(struct xfs *xfsp)
+{
+
+    struct list_head *next;
+    struct list_head *xh;
+    struct xfs_nodelist *xf;
+    struct xfs_node *xn;
+    int counter = 0;
+    int i;
+
+    XFSDEB(XDEBNODE, ("xn_purge: enter\n"));
+    down(&xfsp->node_sem);
+    for(i=0; i < XN_HASHSIZE; i++) {
+
+	xh = &xfsp->node_head.node_lists[i];
+	counter = 2*xfsp->nnodes;
+
+	while (counter-- > 0) {
+	    if (list_empty(xh))
+		break;
+	    next = xh->next;
+	    list_del(next);
+	    list_add_tail(next, xh);
+
+	    xf = list_entry(next, struct xfs_nodelist, node_list);
+
+	    xn = xn_list_entry(xf, struct xfs_node, nodes);
+
+	    up(&xfsp->node_sem);
+	    xfs_force_invalid_xnode(xn);
+	    down(&xfsp->node_sem);
+	}
+    }
+
+    xn_init_head(&xfsp->node_head);
+
+    up(&xfsp->node_sem);
+    XFSDEB(XDEBNODE, ("xn_purge: exit\n"));
+}
+
+int
+xn_deletedp(struct xfs_node *node)
+{
+    XFSDEB(XDEBNODE, ("xn_deletedp: enter\n"));
+    return !list_empty(&node->nodes.node_list);
+    XFSDEB(XDEBNODE, ("xn_deletedp: exit\n"));
+}
+
+void
+xn_init_head(struct xfs_nodelist_head *head)
+{
+    int i;
+    XFSDEB(XDEBNODE, ("xn_init_head: enter\n"));
+    for (i=0; i < XN_HASHSIZE; i++) {
+	INIT_LIST_HEAD(&head->node_lists[i]);
+    }
+    XFSDEB(XDEBNODE, ("xn_init_head: exit\n"));
+}
+
+void 
+xn_insert(struct xfs_nodelist_head *head, struct xfs_node *node)
+{
+    XFSDEB(XDEBNODE, ("xn_insert: enter %d.%d.%d.%d\n", 
+		      node->handle.a,
+		      node->handle.b,
+		      node->handle.c,
+		      node->handle.d));
+    list_add(&node->nodes.node_list, &head->node_lists[xn_hash(&node->handle)]);
+    XFSDEB(XDEBNODE, ("xn_insert: exit\n"));
+}
+
+struct xfs_node *
+xn_lookup(struct xfs_nodelist_head *head, struct xfs_handle *handlep)
+{
+    struct list_head *xh;
+    struct xfs_nodelist *xf;
+    struct xfs_node *xn;
+    int hashvalue;
+
+    XFSDEB(XDEBNODE, ("xn_lookup: enter %d.%d.%d.%d\n",
+		      handlep->a,
+		      handlep->b,
+		      handlep->c,
+		      handlep->d));
+    hashvalue = xn_hash(handlep);
+    XFSDEB(XDEBNODE, ("xn_lookup: hashvalue = %d\n", hashvalue));
+    list_for_each(xh, &head->node_lists[hashvalue]) {
+	if (xh == NULL)
+	    BUG();
+
+	xf = list_entry(xh, struct xfs_nodelist, node_list);
+
+	xn = xn_list_entry(xf, struct xfs_node, nodes);
+
+	if (xfs_handle_eq(&xn->handle, handlep))
+	    return xn;
+    }
+    XFSDEB(XDEBNODE, ("xn_lookup: exit\n"));
+    return NULL;
+}
+
+void
+xn_delete(struct xfs_nodelist_head *head, struct xfs_node *node)
+{
+    XFSDEB(XDEBNODE, ("xn_delete: enter\n"));
+    list_del_init(&node->nodes.node_list);
+    XFSDEB(XDEBNODE, ("xn_delete:exit\n"));
+}
 
 /*
  * Copy the attributes from `attr' into `inode', setting the fields
@@ -92,6 +211,9 @@ static struct inode *
 xfs_iget(struct super_block *sb, struct xfs_msg_node *node,
 	 struct xfs_node *newnode)
 {
+#ifdef LINUX2_3
+    static struct address_space_operations xfs_null_aops;
+#endif
     struct inode *inode;
     struct xfs_attr *attr = &node->attr;
 
@@ -119,7 +241,7 @@ xfs_iget(struct super_block *sb, struct xfs_msg_node *node,
 	inode->i_fop = &xfs_file_operations;
 #endif
 #ifdef LINUX2_3
-        inode->i_mapping->a_ops = &xfs_aops;
+        inode->i_mapping->a_ops = &xfs_null_aops;
 #endif
     } else if (attr->xa_type == XFS_FILE_DIR) {
 	inode->i_op  = &xfs_dir_inode_operations;
@@ -127,7 +249,7 @@ xfs_iget(struct super_block *sb, struct xfs_msg_node *node,
 	inode->i_fop = &xfs_dir_operations;
 #endif
 #ifdef LINUX2_3
-        inode->i_mapping->a_ops = &xfs_aops;
+        inode->i_mapping->a_ops = &xfs_null_aops;
 #endif
     } else if (attr->xa_type == XFS_FILE_LNK) {
 	inode->i_op  = &xfs_link_inode_operations;
@@ -135,7 +257,7 @@ xfs_iget(struct super_block *sb, struct xfs_msg_node *node,
 	inode->i_fop = &xfs_link_operations;
 #endif
 #ifdef LINUX2_3
-	inode->i_mapping->a_ops = &xfs_aops;
+	inode->i_mapping->a_ops = &xfs_null_aops;
 #endif
     } else {
 	inode->i_op  = &xfs_dead_inode_operations;
@@ -144,7 +266,7 @@ xfs_iget(struct super_block *sb, struct xfs_msg_node *node,
 #endif
     }
     
-    inode->u.generic_ip = newnode;
+    VNODE_TO_XNODE(inode) = newnode;
 
     return inode;
 }
@@ -156,7 +278,8 @@ xfs_iget(struct super_block *sb, struct xfs_msg_node *node,
  */
 
 struct xfs_node *
-new_xfs_node(struct xfs *xfsp, struct xfs_msg_node *node)
+new_xfs_node(struct xfs *xfsp, struct xfs_msg_node *node,
+	     struct inode *inode)
 {
     struct xfs_node *result;
     
@@ -169,7 +292,6 @@ new_xfs_node(struct xfs *xfsp, struct xfs_msg_node *node)
     /* Does not allow duplicates */
     result = xfs_node_find(xfsp, &node->handle);
     if (result == 0) {
-	struct inode *v;
 	
 	result = xfs_alloc(sizeof(*result), XFS_MEM_XNODE);
 	if (result == 0) {
@@ -179,20 +301,25 @@ new_xfs_node(struct xfs *xfsp, struct xfs_msg_node *node)
 	
 	memset(result, 0, sizeof(*result));
 	
-	/* Save reference on list */
-	result->next = xfsp->nodes;
-	xfsp->nodes = result;
-	
-	xfsp->nnodes++;
-	
-	result->anonrights = node->anonrights;
 	result->handle = node->handle;
+	result->anonrights = node->anonrights;
 	result->flags = 0;
 	result->tokens = 0;
 	INIT_LIST_HEAD(&result->inactive_list);
 	
-	v=xfs_iget(XFS_TO_VFS(xfsp),node,result);
-	result->vn = v;
+	down(&xfsp->node_sem);
+
+	xn_insert(&xfsp->node_head, result);
+	xfsp->nnodes++;
+
+	up(&xfsp->node_sem);
+	
+	if (inode == NULL)
+	    inode = xfs_iget(XFS_TO_VFS(xfsp),node,result);
+	else
+	    VNODE_TO_XNODE(inode) = result;
+
+	result->vn = inode;
 	/* XXX - handle this case better */
     } else {
 	/* Node is already cached */
@@ -231,7 +358,6 @@ void
 clear_xfs_node(struct xfs_node *node)
 {
     struct xfs *xfsp;
-    struct xfs_node *t;
     
     XFSDEB(XDEBNODE, ("clear_xfs_node starting\n"));
     
@@ -240,22 +366,13 @@ clear_xfs_node(struct xfs_node *node)
     
     xfsp = XFS_FROM_XNODE(node);
     
-    /* First remove from chain. */
-    if (node == xfsp->nodes) {
-	xfsp->nodes = node->next;
-    } else {
-	if (xfsp->nodes == NULL)
-	    goto done;
-	for (t = xfsp->nodes; t->next; t = t->next)
-	    if (t->next == node) {
-		t->next = t->next->next;
-		goto done;
-	    }
-	printk(KERN_EMERG "XFS Panic: clear_xfs_node(0x%p) failed?\n", node);
-	return;
-    }
-    
-done:
+    down(&xfsp->node_sem);
+
+    xn_delete(&xfsp->node_head, node);
+    xfsp->nnodes--;
+
+    up(&xfsp->node_sem);
+
     /* XXX Really need to put back dirty data first. */
     XFS_TOKEN_CLEAR(node, ~0,
 		    XFS_OPEN_MASK | XFS_ATTR_MASK |
@@ -266,11 +383,11 @@ done:
 	DATA_FROM_XNODE(node) = NULL;
     }
     node->flags = 0;
-    xfsp->nnodes--;
     XFSDEB(XDEBNODE, ("clear_xfs_node xnode: %p inode:%p\n",
 		      node, XNODE_TO_VNODE(node)));
     XNODE_TO_VNODE(node)->u.generic_ip = NULL;
     
+    node->flags |= XFS_XDELETED;
     XFSDEB(XDEBNODE, ("clear_xfs_node done\n"));
 }
 
@@ -281,14 +398,20 @@ done:
 void
 free_all_xfs_nodes(struct xfs *xfsp)
 {
-    struct xfs_node *xnode;
+
     XFSDEB(XDEBNODE, ("free_all_xfs_nodes starting\n"));
+
     
-    /* There might still be a few nodes out there, invalidate them */
-    for (xnode = xfsp->nodes; xnode; xnode = xnode->next) {
-	xfs_force_invalid_xnode(xnode);
-    }
-    
+    /*
+     * There might still be a few nodes out there, invalidate them
+     * Move the first entry to the last position on the list and then
+     * try to gc it.
+     */
+
+    xn_purge(xfsp);
+
+    xfsp->root = NULL;
+
     XFSDEB(XDEBNODE, ("free_all_xfs_nodes done\n"));
 }
 
@@ -303,9 +426,10 @@ xfs_node_find(struct xfs *xfsp, xfs_handle *handlep)
     
     XFSDEB(XDEBNODE, ("xfs_node_find\n"));
     
-    for(x = xfsp->nodes; x != NULL; x = x->next)
-	if (xfs_handle_eq(&x->handle, handlep))
-	    break;
+    down(&xfsp->node_sem);
+    x = xn_lookup(&xfsp->node_head, handlep);
+	    up(&xfsp->node_sem);
+
     return x;
 }
 
