@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995 - 2001 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -18,6 +18,9 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL").
+ * 
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -42,7 +45,7 @@
 #include <linux/smp_lock.h>
 #include <linux/smp.h>
 
-RCSID("$Id: xfs_syscalls.c,v 1.64.2.3 2001/08/01 01:03:44 lha Exp $");
+RCSID("$Id: xfs_syscalls.c,v 1.64.2.7 2002/08/29 20:09:38 ahltorp Exp $");
 
 /* 
  * Def pag:
@@ -339,6 +342,9 @@ xfs_fh_to_dentry(struct xfs_cache_handle *handle)
     inode = iget(sb, fh.inode);
     if (inode == NULL) {
 	XFSDEB(XDEBVFOPS, ("xfs_fh_to_dentry: inode == NULL\n"));
+#ifdef LINUX2_3
+	drop_super(sb);
+#endif
 	return ERR_PTR(-ENOENT);
     }
 
@@ -347,6 +353,9 @@ xfs_fh_to_dentry(struct xfs_cache_handle *handle)
 	XFSDEB(XDEBVFOPS, ("xfs_fh_to_dentry: bad generation %u != %u\n",
 			   (unsigned int)inode->i_generation,
 			   (unsigned int)fh.gen));
+#ifdef LINUX2_3
+	drop_super(sb);
+#endif
 	return ERR_PTR(-ENOENT);
     }
 
@@ -356,6 +365,10 @@ xfs_fh_to_dentry(struct xfs_cache_handle *handle)
     
     d_instantiate(dentry, inode);
 
+#ifdef LINUX2_3
+    drop_super(sb);
+#endif
+
     return dentry;
 }
 
@@ -578,13 +591,20 @@ sys_afs_int (int operation,
     case AFSCALL_PIOCTL:
 	XFSDEB(XDEBSYS, ("xfs_pioctl\n"));
 	memcpy(&vice_ioctl,a_paramsP,sizeof(*a_paramsP));
-	if (vice_ioctl.in_size > 2048) {
-	    XFSDEB(XDEBSYS, ("xfs_pioctl_call: got a humongous in packet: "
-			     "opcode: %d (size %d)",
-		   a_opcode, vice_ioctl.in_size));
+
+	if (vice_ioctl.in_size < 0) {
+	    printk(KERN_EMERG 
+		   "xfs: remote pioctl: got a negative data size: opcode: %d",
+		   a_opcode);
 	    error = -EINVAL;
 	    goto unlock;
 	}
+	if (vice_ioctl.in_size > XFS_MSG_MAX_DATASIZE) {
+	    printk(KERN_EMERG
+		   "xfs_pioctl_call: got a humongous in packet: opcode: %d",
+		   a_opcode);
+	    error = -EINVAL;
+	}
 	if (vice_ioctl.in_size != 0) {
 	    if(copy_from_user(&msg.msg,
 			      vice_ioctl.in,
@@ -677,8 +697,12 @@ sys_afs_int (int operation,
 	    error = -EINVAL;
 
 	if (error == 0 && msg2->header.opcode == XFS_MSG_WAKEUP_DATA) {
-	    if(copy_to_user(vice_ioctl.out, msg2->msg,
-			    MIN(msg2->len, vice_ioctl.out_size)) != 0) {
+	    if (vice_ioctl.out_size < 0)
+		msg2->len = 0;
+	    else if (msg2->len > vice_ioctl.out_size)
+		msg2->len = vice_ioctl.out_size;
+
+	    if(copy_to_user(vice_ioctl.out, msg2->msg, msg2->len) != 0) {
 		XFSDEB(XDEBSYS, ("xfs_syscall copy_to_user "
 				 "vice_ioctl.out: %p msg2->msg: %p "
 				 "msg2->len: %d vice_ioctl.out_size: %d\n",
