@@ -14,12 +14,7 @@
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  *
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the Kungliga Tekniska
- *      Hgskolan and its contributors.
- *
- * 4. Neither the name of the Institute nor the names of its contributors
+ * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -36,7 +31,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: xfs_fs.h,v 1.4 1998/12/22 13:16:55 lha Exp $ */
+/* $Id: xfs_fs.h,v 1.9.2.1 2001/01/30 02:14:02 lha Exp $ */
 
 #ifndef _xfs_h
 #define _xfs_h
@@ -47,16 +42,28 @@
 
 /*
  * Filesystem struct.
+ *
+ * LOCKS: `nodes_iter' protects so that there are only one user of the
+ * next_node struct, so that only one can iterate the list (this can
+ * be changed to a list of `next_nodes':s).
+ *
+ * `nodes_modify' need to be hold when `nodes', `next_node' and
+ * `nnodes' are update/read to make sure they are atomicly
+ * updated/read.
  */
-struct xfs {
-  u_int status;		/* Inited, opened or mounted */
-#define XFS_MOUNTED	0x1
-  struct vfs *vfsp;
-  struct xfs_node *root;
-  u_int nnodes;
 
-  struct xfs_node *nodes;		/* replace with hash table */
-  int fd;
+struct xfs {
+    u_int status;			/* Inited, opened or mounted */
+#define XFS_MOUNTED	0x1
+    struct vfs *vfsp;
+    struct xfs_node *root;
+    u_int nnodes;
+    
+    struct xfs_node *nodes;		/* replace with hash table */
+    struct xfs_node *next_node;		/* next node in iter */
+    kmutex_t nodes_iter;		/* iterating over list */
+    kmutex_t nodes_modify;		/* modifing/reading nodes/next_node */
+    int fd;
 };
 
 #define VFS_TO_XFS(v)      ((struct xfs *) ((v)->vfs_data))
@@ -69,10 +76,18 @@ extern struct xfs xfs[];
 
 extern struct vnodeops xfs_vnodeops;
 
+int xfs_unloadable (void);
+void xfs_init_xfs (int instance);
+void xfs_destroy_xfs (int instance);
+
 struct xfs_node *xfs_node_find (struct xfs *, struct xfs_handle *);
-struct xfs_node *new_xfs_node (struct xfs *, struct xfs_msg_node *);
+struct xfs_node *new_xfs_node (struct xfs *, struct xfs_node *,
+			       struct xfs_msg_node *);
 void free_xfs_node (struct xfs_node *);
 void free_all_xfs_nodes (struct xfs *xfsp);
+struct xfs_node *xfs_node_iter_start (struct xfs *xfsp);
+struct xfs_node *xfs_node_iter_next (struct xfs *xfsp);
+void xfs_node_iter_stop (struct xfs *xfsp);
 
 int 
 xfs_dnlc_enter (struct vnode *, char *, struct vnode *);
@@ -80,17 +95,15 @@ xfs_dnlc_enter (struct vnode *, char *, struct vnode *);
 struct vnode *
 xfs_dnlc_lookup (struct vnode *, char *);
 
-void xfs_dnlc_purge (void);
-
 void
 xfs_dnlc_remove(vnode_t *dvp, char *name);
 
 void
-xfs_attr2vattr (const struct xfs_attr *xa, struct vattr *va);
+xfs_attr2vattr (const struct xfs_attr *xa, struct vattr *va, int clear_node);
 
 void
 vattr2xfs_attr (const struct vattr *va, struct xfs_attr *xa);
 
-int xfs_has_pag(const struct xfs_node *xn, pag_t);
+int xfs_has_pag(const struct xfs_node *xn, xfs_pag_t);
 
 #endif /* _xfs_h */
