@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  *
@@ -14,12 +14,7 @@
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  *
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the Kungliga Tekniska
- *      Hgskolan and its contributors.
- *
- * 4. Neither the name of the Institute nor the names of its contributors
+ * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -39,7 +34,7 @@
 #include <config.h>
 #include <xfs/xfs_deb.h>
 
-RCSID("$Id: xfs_deb.c,v 1.3 1998/12/22 13:16:50 lha Exp $");
+RCSID("$Id: xfs_deb.c,v 1.5 2000/10/02 23:53:06 lha Exp $");
 
 /* X is on */
 #define X(y) y
@@ -47,12 +42,12 @@ RCSID("$Id: xfs_deb.c,v 1.3 1998/12/22 13:16:50 lha Exp $");
 #define x(y) 0
 
 int xfsdeb = (0
-	      | X(XDEBDEV)
-	      | X(XDEBMSG)
-	      | X(XDEBDNLC)
-	      | X(XDEBNODE)
-	      | X(XDEBVNOPS)
-	      | X(XDEBVFOPS)
-	      | X(XDEBLKM)
-	      | X(XDEBSYS)
+	      | x(XDEBDEV)
+	      | x(XDEBMSG)
+	      | x(XDEBDNLC)
+	      | x(XDEBNODE)
+	      | x(XDEBVNOPS)
+	      | x(XDEBVFOPS)
+	      | x(XDEBLKM)
+	      | x(XDEBSYS)
 	      );
