@@ -33,7 +33,7 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-RCSID("$Id: output.c,v 1.73.2.1 2001/03/04 04:48:48 lha Exp $");
+RCSID("$Id: output.c,v 1.73.2.2 2002/08/13 15:26:11 lha Exp $");
 #endif
 
 #include <stdio.h>
@@ -487,6 +487,28 @@ print_long (char *where, char *name, Type *type, FILE *f)
     fprintf (f, "printf(\" %s = %%d\", %s%s);", name, where, name);
 }
 
+/*
+ *
+ */
+
+static void
+gen_check_overflow(Type *indextype, Type *subtype, char *num, FILE *f)
+{
+     /* Check if we will overflow */
+     fprintf(f, "{\n");
+     print_type ("overI", indextype, TIN, VDECL, f);
+     fprintf(f, ";\n");
+     fprintf(f, "overI = ((");
+     print_type ("", indextype, TIN, VDECL, f);
+     fprintf(f, ")~((");
+     print_type ("", indextype, TIN, VDECL, f);
+     fprintf(f, ")0) >> 1) / sizeof(");
+     print_type ("", subtype, TIN, VDECL, f);
+     fprintf(f, ");\n");
+     fprintf(f, "if (overI < %s) goto fail;\n", num);
+     fprintf(f, "}\n");
+}
+
 /*
  *
  */
@@ -614,7 +636,16 @@ encode_string (char *name, Type *type, FILE *f, EncodeType encodetype,
 			    "}\n",
 			    type->size);
 	       } else {
-		   fprintf(f, "%s = malloc(len + 1);\n", nname);
+		   fprintf(f, "if (len == (uint32_t) -1) {\n"
+			   "rx_SetCallError(call, ENOMEM);\n"
+			   "goto fail;\n"
+			   "}\n");
+		   fprintf(f, "%s = malloc(len + 1);\n"
+			   "if (%s == NULL) {\n"
+			   "rx_SetCallError(call, ENOMEM);\n"
+			   "goto fail;\n"
+			   "}\n", 
+			   nname, nname);
 	       }
 
 	       fprintf (f, 
@@ -650,7 +681,14 @@ encode_string (char *name, Type *type, FILE *f, EncodeType encodetype,
 			    "goto fail;\n",
 			    type->size);
 	       } else {
-		   fprintf (f, "%s = malloc(len + 1);\n", nname);
+		   fprintf(f, "if (len == (uint32_t) -1) {\n"
+			   "goto fail;\n"
+			   "}\n");
+		   fprintf(f, "%s = malloc(len + 1);\n"
+			   "if (%s == NULL) {\n"
+			   "goto fail;\n"
+			   "}\n", 
+			   nname, nname);
 	       }
 	       fprintf (f,
 			"memcpy (%s, ptr, len);\n"
@@ -783,12 +821,24 @@ encode_varray (char *name, Type *type, FILE *f, EncodeType encodetype,
 {
      char tmp[256];
      Type lentype = {TULONG};
+     Type *indextype;
 	       
      strcpy (tmp, name);
      strcat (tmp, ".len");
 
-     encode_type (tmp, type->indextype ? type->indextype : &lentype,
-		  f, encodetype, side);
+     indextype = type->indextype ? type->indextype : &lentype;
+
+     encode_type (tmp, indextype, f, encodetype, side);
+     if (encodetype == DECODE_MEM || encodetype == DECODE_RX) {
+	 if (type->size != 0)
+	     fprintf (f, "if (%s > %d) goto fail;\n", tmp, type->size);
+	 if (encodetype == DECODE_MEM) {
+	     fprintf (f, "if ((%s * sizeof(", tmp);
+	     print_type ("", type->subtype, TIN, VDECL, f);
+	     fprintf (f, ")) > *total_len) goto fail;\n");
+	 }
+     }
+     gen_check_overflow(indextype, type->subtype, tmp, f);
      if (encodetype == DECODE_MEM || encodetype == DECODE_RX) {
 	 fprintf (f, "%s.val = (", name);
 	 print_type ("*", type->subtype, TIN, VDECL, f);
@@ -1766,7 +1816,7 @@ generate_standard_c_prologue (FILE *f,
 	      "#define bcopy(a,b,c) memcpy((b),(a),(c))\n"
 	      "#endif /* !HAVE_BCOPY */\n\n");
      fprintf (f, "#ifdef RCSID\n"
-	      "RCSID(\"%s generated from %s.xg with $Id: output.c,v 1.73.2.1 2001/03/04 04:48:48 lha Exp $\");\n"
+	      "RCSID(\"%s generated from %s.xg with $Id: output.c,v 1.73.2.2 2002/08/13 15:26:11 lha Exp $\");\n"
 	      "#endif\n\n", filename, basename);
 }
 
@@ -2083,7 +2133,7 @@ generate_tcpdump_patches(FILE *td_file, const char *filename)
 {
     Type optype = {TULONG};
 
-    fprintf(td_file, "/* generated by $Id: output.c,v 1.73.2.1 2001/03/04 04:48:48 lha Exp $ */\n\n");
+    fprintf(td_file, "/* generated by $Id: output.c,v 1.73.2.2 2002/08/13 15:26:11 lha Exp $ */\n\n");
 
     fprintf (td_file, 
 	     "#include <stdio.h>\n"
