@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
+ * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
  * 
@@ -14,12 +14,7 @@
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  * 
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the Kungliga Tekniska
- *      Hgskolan and its contributors.
- * 
- * 4. Neither the name of the Institute nor the names of its contributors
+ * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
@@ -36,7 +31,7 @@
  * SUCH DAMAGE.
  */
 
-/* $Id: types.h,v 1.8 1999/03/19 06:06:52 lha Exp $ */
+/* $Id: types.h,v 1.10 2000/10/02 22:37:20 lha Exp $ */
 
 #ifndef _YDR_TYPES_
 #define _YDR_TYPES_
@@ -68,8 +63,10 @@ typedef struct {
      Type *type;
 } StructEntry;
 
+enum argtype { TIN, TOUT, TINOUT };
+
 typedef struct {
-     enum { TIN, TOUT, TINOUT } argtype;
+     enum argtype argtype;
      char *name;
      Type *type;
 } Argument;
